<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WPS_WC_Autoresponder_Active_Campaign {

	protected static $instance;

	public function __construct() {
		// Load lib
		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/vendor/autoload.php';
	}

	public function get_lists() {
		try {
			$ac = new ActiveCampaign( get_option( 'wps_wc_autoresponder_active_campaign_api_url', '' ), get_option( 'wps_wc_autoresponder_active_campaign_api_secret', '' ) );

			$response = $ac->api( 'list/list_', array( 'ids' => 'all' ) );

			$lists = array();

			if ( $response && isset( $response->success ) ) {
				$response = (array) $response;
				if ( is_array( $response ) ) {
					foreach ( $response as $list ) {
						if ( is_object( $list ) && $list->id && $list->name ) {
							$lists[ $list->id ] = $list->name;
						}
					}
				}
			} else {
				return false;
			}

			return $lists;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public function subscribe( $list_id, $email, $args = array() ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		try {
			$ac = new ActiveCampaign( get_option( 'wps_wc_autoresponder_active_campaign_api_url', '' ), get_option( 'wps_wc_autoresponder_active_campaign_api_secret', '' ) );

			$contact = array(
				'email'              => $email,
				'first_name'         => siar( $args, 'first_name' ),
				'last_name'          => siar( $args, 'last_name' ),
				"p[{$list_id}]"      => $list_id,
				"status[{$list_id}]" => 1,
			);

			if ( siar( $args, 'tags' ) ) {
				$tags = array_filter( explode( ',', siar( $args, 'tags' ) ) );
				if ( $tags ) {
					$contact['tags'] = array_map( 'trim', $tags );
				}
			}

			$contact_sync = $ac->api( 'contact/sync', $contact );

			return $contact_sync && is_object( $contact_sync ) && $contact_sync->success;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WC_Autoresponder_Active_Campaign() {
	return WPS_WC_Autoresponder_Active_Campaign::get_instance();
}
