<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WPS_WC_Autoresponder_Aweber {

	protected static $instance;

	public function __construct() {

	}

	public function generate_api() {
		try {
			// Load lib
			require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/aweber/lib/aweber_api.php';

			$auth = AWeberAPI::getDataFromAweberID( get_option( 'wps_wc_autoresponder_aweber_authorization_code', '' ) );

			if ( $auth ) {
				update_option( 'wps_wc_autoresponder_aweber_consumer_key', siar( $auth, 0 ) );
				update_option( 'wps_wc_autoresponder_aweber_consumer_secret', siar( $auth, 1 ) );
				update_option( 'wps_wc_autoresponder_aweber_access_key', siar( $auth, 2 ) );
				update_option( 'wps_wc_autoresponder_aweber_access_secret', siar( $auth, 3 ) );
				return true;
			}

			return false;
		} catch ( AWeberAPIException $exc ) {
			// ERROR
			return false;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}
	}

	public function get_lists() {
		try {
			// Load lib
			require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/aweber/lib/aweber_api.php';

			$aweber = new AWeberAPI( get_option( 'wps_wc_autoresponder_aweber_consumer_key', '' ), get_option( 'wps_wc_autoresponder_aweber_consumer_secret', '' ) );

			$aweber->adapter->debug = false;

			$account = $aweber->getAccount( get_option( 'wps_wc_autoresponder_aweber_access_key', '' ), get_option( 'wps_wc_autoresponder_aweber_access_secret', '' ) );

			$lists = array();

			if ( isset( $account->lists ) && $account->lists ) {
				foreach ( $account->lists as $offset => $list ) {
					$lists[ $list->id ] = $list->name;
				}
			}

			return $lists;
		} catch ( AWeberAPIException $exc ) {
			// ERROR
			return false;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public function subscribe( $list_id, $email, $args = array() ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		try {
			// Load lib
			require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/aweber/lib/aweber_api.php';

			$aweber = new AWeberAPI( get_option( 'wps_wc_autoresponder_aweber_consumer_key', '' ), get_option( 'wps_wc_autoresponder_aweber_consumer_secret', '' ) );

			$aweber->adapter->debug = false;

			$account = $aweber->getAccount( get_option( 'wps_wc_autoresponder_aweber_access_key', '' ), get_option( 'wps_wc_autoresponder_aweber_access_secret', '' ) );

			$account_id = $account->id;
			$list       = $account->loadFromUrl( "/accounts/{$account_id}/lists/{$list_id}" );

			$params = array(
				'email'       => $email,
				'ip_address'  => $_SERVER['REMOTE_ADDR'],
				'ad_tracking' => '',
				'misc_notes'  => '',
				'name'        => trim( siar( $args, 'first_name' ) . ' ' . siar( $args, 'first_name' ) ),
			);

			$new_subscriber = $list->subscribers->create( $params );

			return isset( $new_subscriber ) && $new_subscriber;
		} catch ( AWeberAPIException $exc ) {
			// ERROR
			return false;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WC_Autoresponder_Aweber() {
	return WPS_WC_Autoresponder_Aweber::get_instance();
}
