<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WPS_WC_Autoresponder_Campaign_Monitor {

	protected static $instance;

	public function __construct() {
		// Load lib
		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/vendor/autoload.php';
	}

	public function get_lists() {
		try {
			$wrap = new CS_REST_Clients(
				get_option( 'wps_wc_autoresponder_campaign_monitor_client_id', '' ),
				array( 'api_key' => get_option( 'wps_wc_autoresponder_campaign_monitor_api_key', '' ) )
			);

			$result = $wrap->get_lists();

			$lists = array();

			if ( $result->was_successful() ) {
				if ( isset( $result->response ) && $result->response ) {
					foreach ( $result->response as $list ) {
						$lists[ $list->ListID ] = $list->Name;
					}
				}
			} else {
				return false;
			}

			return $lists;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public function subscribe( $list_id, $email, $args = array() ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		try {
			$wrap = new CS_REST_Subscribers(
				$list_id,
				array( 'api_key' => get_option( 'wps_wc_autoresponder_campaign_monitor_api_key', '' ) )
			);

			$result = $wrap->add(
				array(
					'EmailAddress'   => $email,
					'Name'           => trim( siar( $args, 'first_name' ) . ' ' . siar( $args, 'last_name' ) ),
					'ConsentToTrack' => 'yes',
					'Resubscribe'    => true,
				)
			);

			return $result->was_successful();
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WC_Autoresponder_Campaign_Monitor() {
	return WPS_WC_Autoresponder_Campaign_Monitor::get_instance();
}
