<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WPS_WC_Autoresponder_Constant_Contact {

	protected static $instance;

	public function __construct() {

	}

	public function get_lists() {
		$contact_contact_endpoint = 'https://api.constantcontact.com/v2/lists';

		$contact_contact_endpoint = add_query_arg(
			array(
				'api_key'      => get_option( 'wps_wc_autoresponder_constant_contact_api_key', '' ),
				'access_token' => get_option( 'wps_wc_autoresponder_constant_contact_access_token', '' ),
			),
			$contact_contact_endpoint
		);

		$response = wp_remote_post(
			$contact_contact_endpoint,
			array(
				'method'      => 'GET',
				'timeout'     => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking'    => true,
				'headers'     => array(),
				'body'        => array(),
				'cookies'     => array(),
			)
		);

		$lists_tmp = false;

		if ( ! is_wp_error( $response ) ) {
			$lists_tmp = wp_remote_retrieve_body( $response );
		}

		$lists_tmp = ! empty( $lists_tmp ) && $lists_tmp ? json_decode( $lists_tmp, true ) : $lists_tmp;

		$lists = array();

		if ( $lists_tmp && is_array( $lists_tmp ) && ! siars( $lists_tmp, '0/error_key' ) ) {
			foreach ( $lists_tmp as $list ) {
				if ( siar( $list, 'id' ) && siar( $list, 'name' ) ) {
					$lists[ siar( $list, 'id' ) ] = siar( $list, 'name' );
				}
			}
		} else {
			return false;
		}

		return $lists;
	}

	public function subscribe( $list_id, $email, $args = array() ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		$contact_contact_endpoint = 'https://api.constantcontact.com/v2/contacts';

		$contact_contact_endpoint = add_query_arg(
			array(
				'api_key'      => get_option( 'wps_wc_autoresponder_constant_contact_api_key', '' ),
				'access_token' => get_option( 'wps_wc_autoresponder_constant_contact_access_token', '' ),
				'email'        => urlencode( $email ),
			),
			$contact_contact_endpoint
		);

		$response = wp_remote_post(
			$contact_contact_endpoint,
			array(
				'method'      => 'GET',
				'timeout'     => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking'    => true,
				'headers'     => array(),
				'body'        => array(),
				'cookies'     => array(),
			)
		);

		$response_contact = false;

		if ( ! is_wp_error( $response ) ) {
			$response_contact = wp_remote_retrieve_body( $response );
		}

		$response_contact = ! empty( $response_contact ) && $response_contact ? json_decode( $response_contact, true ) : $response_contact;
		$contact          = $response_contact ? siars( $response_contact, 'results/0' ) : false;

		if ( $contact ) {
			// Update
			$update_details = array(
				'id'              => siar( $contact, 'id' ),
				'lists'           => array_merge( siar( $contact, 'lists', array() ), array( array( 'id' => $list_id ) ) ),
				'first_name'      => siar( $args, 'first_name' ),
				'last_name'       => siar( $args, 'last_name' ),
				'email_addresses' => $contact['email_addresses'],
			);

			$contact_contact_endpoint = 'https://api.constantcontact.com/v2/contacts/' . siar( $contact, 'id' );

			$contact_contact_endpoint = add_query_arg(
				array(
					'api_key'      => get_option( 'wps_wc_autoresponder_constant_contact_api_key', '' ),
					'access_token' => get_option( 'wps_wc_autoresponder_constant_contact_access_token', '' ),
					'action_by'    => 'ACTION_BY_OWNER',
				),
				$contact_contact_endpoint
			);

			$ch = curl_init( $contact_contact_endpoint );
			curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
			curl_setopt( $ch, CURLOPT_CUSTOMREQUEST, 'PUT' );
			curl_setopt( $ch, CURLOPT_HTTPHEADER, array( 'Content-Type: application/json' ) );
			curl_setopt( $ch, CURLOPT_POSTFIELDS, json_encode( $update_details ) );
			$response = curl_exec( $ch );

			return $response ? true : false;
		} else {
			// Create
			$params = array(
				'addresses'       => array(),
				'lists'           => array( array( 'id' => $list_id ) ),
				'first_name'      => siar( $args, 'first_name' ),
				'last_name'       => siar( $args, 'last_name' ),
				'email_addresses' => array( array( 'email_address' => $email ) ),
				'cell_phone'      => '',
				'company_name'    => '',
				'fax'             => '',
				'job_title'       => '',
				'work_phone'      => '',
				'prefix_name'     => '',
				'confirmed'       => false,
				'home_phone'      => '',
			);

			$contact_contact_endpoint = 'https://api.constantcontact.com/v2/contacts';
			$contact_contact_endpoint = add_query_arg(
				array(
					'api_key'      => get_option( 'wps_wc_autoresponder_constant_contact_api_key', '' ),
					'access_token' => get_option( 'wps_wc_autoresponder_constant_contact_access_token', '' ),
					'action_by'    => 'ACTION_BY_OWNER',
				),
				$contact_contact_endpoint
			);

			$ch = curl_init( $contact_contact_endpoint );
			curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
			curl_setopt( $ch, CURLOPT_CUSTOMREQUEST, 'POST' );
			curl_setopt( $ch, CURLOPT_HTTPHEADER, array( 'Content-Type: application/json' ) );
			curl_setopt( $ch, CURLOPT_POSTFIELDS, json_encode( $params ) );
			$response = curl_exec( $ch );

			return $response ? true : false;
		}

		return false;
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WC_Autoresponder_Constant_Contact() {
	return WPS_WC_Autoresponder_Constant_Contact::get_instance();
}
