<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WPS_WC_Autoresponder_ConvertKit {

	protected static $instance;

	public function __construct() {
		// Load lib
		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/vendor/autoload.php';
	}

	public function get_lists() {
		try {
			$response = wp_remote_get( 'https://api.convertkit.com/v3/forms?api_key=' . get_option( 'wps_wc_autoresponder_convertkit_api_key', '' ) );

			$forms = array();

			if ( is_array( $response ) && ! is_wp_error( $response ) ) {
				$response_forms = json_decode( $response['body'], true );

				if ( siar( $response_forms, 'error' ) ) {
					return false;
				} elseif ( siar( $response_forms, 'forms' ) ) {
					foreach ( siar( $response_forms, 'forms' ) as $form ) {
						$forms[ $form['id'] ] = $form['name'];
					}
				}

				return $forms;
			}
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public function get_sequences() {
		try {
			$response = wp_remote_get( 'https://api.convertkit.com/v3/sequences?api_key=' . get_option( 'wps_wc_autoresponder_convertkit_api_key', '' ) );

			$sequences = array();

			if ( is_array( $response ) && ! is_wp_error( $response ) ) {
				$response_sequences = json_decode( $response['body'], true );

				if ( siar( $response_sequences, 'error' ) ) {
					return false;
				} elseif ( siar( $response_sequences, 'courses' ) ) {
					foreach ( siar( $response_sequences, 'courses' ) as $sequence ) {
						$sequences[ $sequence['id'] ] = $sequence['name'];
					}
				}
			}

			return $sequences;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public function subscribe( $form_id, $email, $args = array() ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		try {
			$response = wp_remote_post(
				'https://api.convertkit.com/v3/forms/' . $form_id . '/subscribe',
				array(
					'method'      => 'POST',
					'timeout'     => 15,
					'redirection' => 5,
					'httpversion' => '1.0',
					'blocking'    => true,
					'headers'     => array(),
					'body'        => array(
						'api_key'    => get_option( 'wps_wc_autoresponder_convertkit_api_key', '' ),
						'email'      => $email,
						'first_name' => siar( $args, 'first_name' ),
						'fields'     => array( 'last_name' => siar( $args, 'last_name' ) ),
					),
					'cookies'     => array(),
				)
			);

			return $response && ! is_wp_error( $response );
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public function subscribe_sequence( $sequence_id, $email, $args = array() ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		try {
			$response = wp_remote_post(
				'https://api.convertkit.com/v3/sequences/' . $sequence_id . '/subscribe',
				array(
					'method'      => 'POST',
					'timeout'     => 15,
					'redirection' => 5,
					'httpversion' => '1.0',
					'blocking'    => true,
					'headers'     => array(),
					'body'        => array(
						'api_key'    => get_option( 'wps_wc_autoresponder_convertkit_api_key', '' ),
						'email'      => $email,
						'first_name' => siar( $args, 'first_name' ),
						'fields'     => array( 'last_name' => siar( $args, 'last_name' ) ),
					),
					'cookies'     => array(),
				)
			);

			return $response && ! is_wp_error( $response );
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WC_Autoresponder_ConvertKit() {
	return WPS_WC_Autoresponder_ConvertKit::get_instance();
}
