<?php
use Getresponse\Sdk\Client\Exception\MalformedResponseDataException;
use Getresponse\Sdk\Client\Operation\Pagination;
use Getresponse\Sdk\GetresponseClientFactory;
use Getresponse\Sdk\Operation\Campaigns\GetCampaign\GetCampaign;
use Getresponse\Sdk\Operation\Campaigns\GetCampaigns\GetCampaigns;
use Getresponse\Sdk\Operation\Contacts\CreateContact\CreateContact;
use Getresponse\Sdk\Operation\CustomFields\GetCustomFields\GetCustomFields;
use Getresponse\Sdk\Operation\CustomFields\GetCustomFields\GetCustomFieldsSearchQuery;
use Getresponse\Sdk\Operation\Model\CampaignReference;
use Getresponse\Sdk\Operation\Model\NewContact;
use Getresponse\Sdk\Operation\Model\NewContactCustomFieldValue;
use Getresponse\Sdk\Operation\Model\NewContactTag;
use Getresponse\Sdk\Operation\Tags\GetTags\GetTags;
use Getresponse\Sdk\Operation\Tags\GetTags\GetTagsSearchQuery;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WPS_WC_Autoresponder_GetResponse {

	protected static $instance;

	public function __construct() {
		// Load lib
		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/vendor/autoload.php';
		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/vendor/guzzlehttp/psr7/src/functions_include.php';	// FIX: Psr Conflict 
	}

	public function get_lists() {
		try {			
			$client = GetresponseClientFactory::createWithApiKey( get_option( 'wps_wc_autoresponder_getresponse_api_key', '' ) );

			$campaignsOperation = new GetCampaigns();
			$campaignsOperation->setPagination( new Pagination( 1, 1000 ) );
			$response = $client->call( $campaignsOperation );

			if ( $response->isSuccess() ) {
				$campaignsArray = array();
				$campaignList   = $response->getData();

				if ( $campaignList ) {
					foreach ( $campaignList as $campaign ) {
						$campaignsArray[ $campaign['campaignId'] ] = $campaign['name'];
					}
				}

				return $campaignsArray;
			} else {
				// ERROR
				// $errorData = $response->getData();
				return false;
			}
		} catch ( MalformedResponseDataException $e ) {
			// ERROR
			return false;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public function subscribe( $campaign_id, $email, $args = array() ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		try {
			$client = GetresponseClientFactory::createWithApiKey( get_option( 'wps_wc_autoresponder_getresponse_api_key', '' ) );

			$newContact = new NewContact(
				new CampaignReference( $campaign_id ),
				$email
			);

			$newContact->setName( trim( siar( $args, 'first_name' ) . ' ' . siar( $args, 'last_name' ) ) );

			$createContact = new CreateContact( $newContact );

			$createContactResponse = $client->call( $createContact );

			return $createContactResponse->isSuccess();
		} catch ( MalformedResponseDataException $e ) {
			// ERROR
			return false;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WC_Autoresponder_GetResponse() {
	return WPS_WC_Autoresponder_GetResponse::get_instance();
}
