<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WPS_WC_Autoresponder_Mailchimp {

	protected static $instance;

	public function __construct() {
		// Load lib
		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/vendor/autoload.php';
	}

	public function get_lists() {
		try {
			$mailchimp = new MailchimpMarketing\ApiClient();

			$api_key   = get_option( 'wps_wc_autoresponder_mailchimp_api_key', '' );
			$key_split = explode( '-', trim( $api_key ) );

			$mailchimp->setConfig(
				array(
					'apiKey' => trim( $api_key ),
					'server' => trim( siar( $key_split, 1 ) ),
				)
			);

			$response = $mailchimp->lists->getAllLists();

			$lists = array();

			if ( $response && $response->total_items && $response->lists ) {
				foreach ( $response->lists as $list ) {
					$lists[ $list->id ] = $list->name;
				}
			}

			return $lists;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public function subscribe( $list_id, $email, $args = array() ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		try {
			$mailchimp = new MailchimpMarketing\ApiClient();

			$api_key   = get_option( 'wps_wc_autoresponder_mailchimp_api_key', '' );
			$key_split = explode( '-', trim( $api_key ) );

			$mailchimp->setConfig(
				array(
					'apiKey' => trim( $api_key ),
					'server' => trim( siar( $key_split, 1 ) ),
				)
			);

			$member = array(
				'email_address' => $email,
				'status'        => 'subscribed',
				'merge_fields'  => array(
					'FNAME' => siar( $args, 'first_name' ),
					'LNAME' => siar( $args, 'last_name' ),
				),
			);

			if ( siar( $args, 'tags' ) ) {
				$tags = array_filter( explode( ',', siar( $args, 'tags' ) ) );
				if ( $tags ) {
					$member['tags'] = array_map( 'trim', $tags );
				}
			}

			$response = $mailchimp->lists->addListMember( $list_id, $member );

			return isset( $response ) && $response;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WC_Autoresponder_Mailchimp() {
	return WPS_WC_Autoresponder_Mailchimp::get_instance();
}
