<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WPS_WC_Autoresponder_Send_Reach {

	protected static $instance;

	public function __construct() {
		// Load lib
		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/send-reach/v3/MailWizzApi/Autoloader.php';
	}

	public function get_lists() {
		try {
			// register the autoloader.
			MailWizzApi_Autoloader::register();

			// configuration object
			$config = new MailWizzApi_Config(
				array(
					'apiUrl'     => 'http://dashboard.sendreach.com/api/index.php',
					'publicKey'  => get_option( 'wps_wc_autoresponder_send_reach_api_key', '' ),
					'privateKey' => get_option( 'wps_wc_autoresponder_send_reach_api_secret', '' ),
					// components
					'components' => array(
						'cache' => array(
							'class'     => 'MailWizzApi_Cache_File',
							'filesPath' => WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/send-reach/v3/MailWizzApi/Cache/data/cache', // make sure it is writable by webserver
						),
					),
				)
			);

			// now inject the configuration and we are ready to make api calls
			MailWizzApi_Base::setConfig( $config );

			// create the lists endpoint:
			$endpoint = new MailWizzApi_Endpoint_Lists();

			// GET ALL ITEMS
			$result = $endpoint->getLists( $pageNumber = 1, $perPage = 1000 );

			$result = ( isset( $result->body ) && isset( $result->body['data'] ) ) ? $result->body['data']['records'] : array();

			$lists = array();

			if ( is_array( $result ) && $result ) {
				foreach ( $result as $list_array ) {
					if ( siar( $list_array, 'general' ) && is_array( siar( $list_array, 'general' ) ) ) {
						$list = siar( $list_array, 'general' );

						if ( siar( $list, 'list_uid' ) && siar( $list, 'name' ) ) {
							$lists[ siar( $list, 'list_uid' ) ] = siar( $list, 'name' );
						}
					}
				}
			} else {
				return false;
			}

			return $lists;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public function subscribe( $list_id, $email, $args = array() ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		try {
			// register the autoloader.
			MailWizzApi_Autoloader::register();

			// configuration object
			$config = new MailWizzApi_Config(
				array(
					'apiUrl'     => 'http://dashboard.sendreach.com/api/index.php',
					'publicKey'  => get_option( 'wps_wc_autoresponder_send_reach_api_key', '' ),
					'privateKey' => get_option( 'wps_wc_autoresponder_send_reach_api_secret', '' ),
					// components
					'components' => array(
						'cache' => array(
							'class'     => 'MailWizzApi_Cache_File',
							'filesPath' => WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/send-reach/v3/MailWizzApi/Cache/data/cache', // make sure it is writable by webserver
						),
					),
				)
			);

			// now inject the configuration and we are ready to make api calls
			MailWizzApi_Base::setConfig( $config );

			// create the lists endpoint:
			$endpoint = new MailWizzApi_Endpoint_ListSubscribers();

			// CREATE / UPDATE EXISTING SUBSCRIBER
			$response = $endpoint->createUpdate(
				$list_id,
				array(
					'EMAIL' => $email,
					'FNAME' => siar( $args, 'first_name' ),
					'LNAME' => siar( $args, 'last_name' ),
				)
			);

			return isset( $response ) && $response;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WC_Autoresponder_Send_Reach() {
	return WPS_WC_Autoresponder_Send_Reach::get_instance();
}
