<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WPS_WC_Autoresponder_Sendinblue {

	protected static $instance;

	public function __construct() {
		// Load lib
		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/vendor/autoload.php';
	}

	public function get_lists() {
		try {
			$config = SendinBlue\Client\Configuration::getDefaultConfiguration()->setApiKey( 'api-key', get_option( 'wps_wc_autoresponder_sendinblue_api_key', '' ) );

			$apiInstance = new SendinBlue\Client\Api\ContactsApi(
				// If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
				// This is optional, `GuzzleHttp\Client` will be used as default.
				new GuzzleHttp\Client(),
				$config
			);

			$result = $apiInstance->getLists();

			$lists = array();

			if ( $result && $result->getCount() && $result->getLists() ) {
				foreach ( $result->getLists() as $list ) {
					$lists[ $list['id'] ] = $list['name'];
				}
			} else {
				return false;
			}

			return $lists;
		} catch ( Exception $e ) {
			return false;
		}

		return false;
	}

	public function subscribe( $list_id, $email, $args = array() ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		try {
			$config = SendinBlue\Client\Configuration::getDefaultConfiguration()->setApiKey( 'api-key', get_option( 'wps_wc_autoresponder_sendinblue_api_key', '' ) );

			$apiInstance = new SendinBlue\Client\Api\ContactsApi(
				// If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
				// This is optional, `GuzzleHttp\Client` will be used as default.
				new GuzzleHttp\Client(),
				$config
			);

			$result = $apiInstance->CreateContact(
				array(
					'email'         => $email,
					'listIds'       => array( intval( $list_id ) ),
					'updateEnabled' => true,
					'attributes'    => array(
						'FIRSTNAME' => siar( $args, 'first_name' ),
						'LASTNAME'  => siar( $args, 'last_name' ),
					),
				)
			);

			return isset( $result ) && $result;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WC_Autoresponder_Sendinblue() {
	return WPS_WC_Autoresponder_Sendinblue::get_instance();
}
