<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WPS_WC_Autoresponder_Vertical_Response {

	protected static $instance;

	public function __construct() {
		$this->wsdl = 'https://api.verticalresponse.com/wsdl/1.0/VRAPI.wsdl';
	}

	public function get_lists() {
		try {
			$vr  = new SoapClient( $this->wsdl, array() );
			$sid = $vr->login(
				array(
					'username'                 => get_option( 'wps_wc_autoresponder_vertical_response_username', '' ),
					'password'                 => get_option( 'wps_wc_autoresponder_vertical_response_password', '' ),
					'session_duration_minutes' => 10,
				)
			);

			$vr_lists = $vr->enumerateLists(
				array(
					'session_id'         => $sid,
					'type'               => 'email',
					'include_field_info' => true,
					'limit'              => 1000,
				)
			);

			$lists = array();

			if ( $vr_lists ) {
				foreach ( $vr_lists as $list ) {
					if ( $list->is_master !== 1 ) {
						$lists[ $list->id ] = $list->name;
					}
				}
			}

			return $lists;
		} catch ( SoapFault $exception ) {
			// ERROR
			return false;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public function subscribe( $list_id, $email, $args = array() ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		try {
			$vr  = new SoapClient( $this->wsdl, array() );
			$sid = $vr->login(
				array(
					'username'                 => get_option( 'wps_wc_autoresponder_vertical_response_username', '' ),
					'password'                 => get_option( 'wps_wc_autoresponder_vertical_response_password', '' ),
					'session_duration_minutes' => 10,
				)
			);

			$list_member = array(
				'session_id'  => $sid,
				'list_member' => array(
					'list_id'     => $list_id,
					'member_data' => array(
						array(
							'name'  => 'email_address',
							'value' => $email,
						),
						array(
							'name'  => 'first_name',
							'value' => siar( $args, 'first_name' ),
						),
						array(
							'name'  => 'last_name',
							'value' => siar( $args, 'last_name' ),
						),
					),
				),
			);

			$response = $vr->addListMember( $list_member );

			return isset( $response ) && $response;
		} catch ( SoapFault $exception ) {
			// ERROR
			return false;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}

		return false;
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WC_Autoresponder_Vertical_Response() {
	return WPS_WC_Autoresponder_Vertical_Response::get_instance();
}
