<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WPS_WC_Autoresponder_Helper {

	protected static $instance;

	public function __construct() {

	}

	public function is_mymail_support() {
		include_once ABSPATH . 'wp-admin/includes/plugin.php';
		return is_plugin_active( 'myMail/myMail.php' );
	}

	public function get_mymail_data() {
		if ( ! $this->is_mymail_support() ) {
			return false;
		}

		$lists = array();

		if ( defined( 'MYMAIL_VERSION' ) && version_compare( MYMAIL_VERSION, '2.0', '>=' ) ) {
			global $wpdb;

			$maymail_lists = $wpdb->get_results( "SELECT * FROM {$wpdb->prefix}mymail_lists" );

			if ( $maymail_lists ) {
				foreach ( $maymail_lists as $list ) {
					$lists[ $list->slug ] = $list->name;
				}
			}
		} else {
			$args = array(
				'orderby'      => 'name',
				'order'        => 'ASC',
				'hide_empty'   => false,
				'exclude'      => array(),
				'exclude_tree' => array(),
				'include'      => array(),
				'number'       => '',
				'fields'       => 'all',
				'slug'         => '',
				'parent'       => '',
				'hierarchical' => true,
				'child_of'     => 0,
				'get'          => '',
				'name__like'   => '',
				'pad_counts'   => false,
				'offset'       => '',
				'search'       => '',
				'cache_domain' => 'core',
			);

			$terms = get_terms( 'newsletter_lists', $args );

			if ( $terms ) {
				foreach ( $terms as $term ) {
					$lists[ $term->slug ] = $term->name;
				}
			}
		}

		return $lists;
	}

	public function mymail_subscribe( $list_id, $email, $args = array() ) {
		if ( ! $this->is_mymail_support() ) {
			return false;
		}

		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		try {
			$userdata = array(
				'firstname' => siar( $args, 'first_name' ),
				'lastname'  => siar( $args, 'last_name' ),
			);

			$response = mymail_subscribe( $email, $userdata, array( $list_id ), false, true );

			return isset( $response ) && $response;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}
	}

	public function is_wysija_support() {
		return class_exists( 'WYSIJA' ) ? true : false;
	}

	public function get_wysija_data() {
		if ( ! $this->is_wysija_support() ) {
			return false;
		}

		$lists        = array();
		$model_list   = WYSIJA::get( 'list', 'model' );
		$wysija_lists = $model_list->getLists();

		if ( $wysija_lists ) {
			foreach ( $wysija_lists as $list ) {
				$lists[ $list['list_id'] ] = $list['name'];
			}
		}

		return $lists;
	}

	public function wysija_subscribe( $list_id, $email, $args = array() ) {
		if ( ! $this->is_wysija_support() ) {
			return false;
		}

		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		try {
			$wysija_data = array(
				'user'      => array(
					'email'     => $email,
					'firstname' => siar( $args, 'first_name' ),
					'lastname'  => siar( $args, 'last_name' ),
				),
				'user_list' => array(
					'list_ids' => array( $list_id ),
				),
			);

			$WYSIJAuserHelper = &WYSIJA::get( 'user', 'helper' );
			$response         = $WYSIJAuserHelper->addSubscriber( $wysija_data );

			return isset( $response ) && $response;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}
	}

	public function is_mailster_support() {
		return defined( 'MAILSTER_VERSION' ) ? true : false;
	}

	public function get_mailster_data() {
		if ( ! $this->is_mailster_support() ) {
			return false;
		}

		$mailster_lists = mailster( 'lists' )->get();

		$lists = array();

		if ( $mailster_lists ) {
			foreach ( $mailster_lists as $list ) {
				$lists[ $list->slug ] = $list->name;
			}
		}

		return $lists;
	}

	public function mailster_subscribe( $list_id, $email, $args = array() ) {
		if ( ! $this->is_mailster_support() ) {
			return false;
		}

		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		try {
			$userdata = array(
				'firstname' => siar( $args, 'first_name' ),
				'lastname'  => siar( $args, 'last_name' ),
			);

			$response = mailster_subscribe( $email, $userdata, array( $list_id ), false, true );

			return isset( $response ) && $response;
		} catch ( Exception $e ) {
			// ERROR
			return false;
		}
	}

	public function is_mailpoet_support() {
		if ( defined( 'MAILPOET_VERSION' ) && version_compare( MAILPOET_VERSION, '3.0', '>=' ) ) {
			return true;
		}

		return false;
	}

	public function get_mailpoet_data() {
		if ( ! $this->is_mailpoet_support() ) {
			return false;
		}

		$lists          = array();
		$mailpoet_lists = \MailPoet\API\API::MP( 'v1' )->getLists();

		if ( $mailpoet_lists ) {
			foreach ( $mailpoet_lists as $list ) {
				$lists[ $list['id'] ] = $list['name'];
			}
		}

		return $lists;
	}

	public function mailpoet_subscribe( $list_id, $email, $args = array() ) {
		if ( ! $this->is_mailpoet_support() ) {
			return false;
		}

		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		$subscriber = false;

		try {
			$subscriber = \MailPoet\API\API::MP( 'v1' )->getSubscriber( $email );
		} catch ( Exception $exception ) {
			// ERROR
		}

		$lists = array_map( 'intval', array( $list_id ) );

		if ( ! $subscriber ) {
			$subscriber_data = array(
				'email'      => sanitize_text_field( $email ),
				'first_name' => sanitize_text_field( siar( $args, 'first_name' ) ),
				'last_name'  => sanitize_text_field( siar( $args, 'last_name' ) ),
			);

			try {
				$subscriber = \MailPoet\API\API::MP( 'v1' )->addSubscriber( $subscriber_data, $lists );
				return isset( $subscriber ) && $subscriber;
			} catch ( Exception $exception ) {
				// ERROR
				return false;
			}
		} else {
			try {
				$response = \MailPoet\API\API::MP( 'v1' )->subscribeToLists( $email, $lists );
				return isset( $response ) && $response;
			} catch ( Exception $exception ) {
				// ERROR
				return false;
			}
		}
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WC_Autoresponder_Helper() {
	return WPS_WC_Autoresponder_Helper::get_instance();
}
