<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WPS_WC_Autoresponder_Plugin_Update {

	protected static $instance;

	public function __construct() {
		add_filter( 'plugins_api', array( $this, 'check_plugin_info' ), 20, 3 );
		add_filter( 'pre_set_site_transient_update_plugins', array( $this, 'transient_update_plugins' ), 21, 1 );
		add_action( 'admin_init', array( $this, 'maybe_update_plugin_database' ), 15 );
		add_action( 'wps_wc_autoresponder_after_save_settings_section', array( $this, 'validate_purchase' ), 20, 1 );
		add_action( 'in_plugin_update_message-' . WPS_WOOCOMMERCE_AUTORESPONDER_BASENAME, array( $this, 'plugin_update_message' ), 20, 2 );
	}

	public function plugin_update_message( $plugin_data, $response ) {
		if ( $response && isset( $response->new_version ) && empty( $response->package ) ) {
			printf(
				' %s <a href="%s">%s</a> %s',
				esc_html__( 'To receive automatic updates license activation is required. Please visit', 'wps-woocommerce-autoresponder' ),
				esc_url( admin_url( 'admin.php?page=wc-settings&tab=wps_wc_autoresponder&section=license' ) ),
				esc_html__( 'settings', 'wps-woocommerce-autoresponder' ),
				esc_html__( 'to activate license', 'wps-woocommerce-autoresponder' )
			);
		}
	}

	public function check_plugin_info( $result, $action, $args ) {
		if ( 'plugin_information' !== $action ) {
			return $result;
		}

		if ( empty( $args->slug ) || 'wps-woocommerce-autoresponder' !== $args->slug ) {
			return $result;
		}

		$response = wp_remote_post(
			'https://wpstriker.com/?page=wps_info',
			array(
				'method'      => 'POST',
				'timeout'     => 15,
				'redirection' => 5,
				'httpversion' => '1.1',
				'sslverify'   => false,
				'blocking'    => true,
				'body'        => array(),
			)
		);

		$information = false;

		if ( 200 === wp_remote_retrieve_response_code( $response ) ) {
			$response    = wp_remote_retrieve_body( $response );
			$information = $response ? json_decode( $response, true ) : false;
		}

		return $information ? (object) $information : $result;
	}

	public function transient_update_plugins( $transient ) {
		$response = wp_remote_post(
			'https://wpstriker.com/?page=wps_check',
			array(
				'method'      => 'POST',
				'timeout'     => 15,
				'redirection' => 5,
				'httpversion' => '1.1',
				'sslverify'   => false,
				'blocking'    => true,
				'body'        => array(
					'code' => get_option( 'wps_wc_autoresponder_license_key', '' ),
					'url'  => site_url(),
				),
			)
		);

		$information = false;

		if ( 200 === wp_remote_retrieve_response_code( $response ) ) {
			$response    = wp_remote_retrieve_body( $response );
			$information = $response ? json_decode( $response, true ) : false;

			if ( $information && isset( $information['new_version'] ) ) {
				if ( version_compare( WPS_WOOCOMMERCE_AUTORESPONDER_VERSION, $information['new_version'], '<' ) ) {
					$transient->response[ WPS_WOOCOMMERCE_AUTORESPONDER_BASENAME ] = (object) $information;
					unset( $transient->no_update[ WPS_WOOCOMMERCE_AUTORESPONDER_BASENAME ] );
				} else {
					$transient->no_update[ WPS_WOOCOMMERCE_AUTORESPONDER_BASENAME ] = (object) $information;
					unset( $transient->response[ WPS_WOOCOMMERCE_AUTORESPONDER_BASENAME ] );
				}
			}
		}

		return $transient;
	}

	public function maybe_update_plugin_database() {
		$wps_wc_autoresponder_version = get_option( 'wps_wc_autoresponder_version', '' );
		if ( ! empty( $wps_wc_autoresponder_version ) ) {
			if ( WPS_WOOCOMMERCE_AUTORESPONDER_VERSION !== $wps_wc_autoresponder_version ) {
				update_option( 'wps_wc_autoresponder_version', WPS_WOOCOMMERCE_AUTORESPONDER_VERSION );
			}

			return; // No database upgrade needed
		}

		update_option( 'wps_wc_autoresponder_version', WPS_WOOCOMMERCE_AUTORESPONDER_VERSION );

		if ( empty( get_option( 'wooc_ar_version', '' ) ) ) {
			return; // Fresh install, no need to upgrade database
		}

		// make database upgrade from 2.x to 3.x.x
		global $wpdb;

		// Product Settings
		$post_metas = $wpdb->get_results( "SELECT * FROM {$wpdb->postmeta} WHERE `meta_key` = 'wooc_ar_autoresponder'" );

		if ( $post_metas ) {
			foreach ( $post_metas as $post_meta ) {
				$post_ID = $post_meta->post_id;

				if ( 'product' !== get_post_type( $post_ID ) ) {
					continue;
				}

				delete_post_meta( $post_ID, 'wooc_ar_autoresponder' );

				$wooc_ar_autoresponder = maybe_unserialize( $post_meta->meta_value );

				if ( ! is_array( $wooc_ar_autoresponder ) ) {
					$wooc_ar_autoresponder = maybe_unserialize( $wooc_ar_autoresponder );
				}

				if ( $wooc_ar_autoresponder && is_array( $wooc_ar_autoresponder ) ) {
					// Settings
					update_post_meta( $post_ID, 'wps_wc_autoresponder_product_enable', siar( $wooc_ar_autoresponder, 'is_autoresponder' ) ? true : false );

					$subscribe_upon = siar( $wooc_ar_autoresponder, 'subscribe_at' );
					if ( $subscribe_upon ) {
						if ( 'order_proccessing' === $subscribe_upon ) {
							$subscribe_upon = 'payment_complete';
						}

						update_post_meta( $post_ID, 'wps_wc_autoresponder_product_subscribe_upon', $subscribe_upon );
					}

					if ( siar( $wooc_ar_autoresponder, 'opt_label' ) ) {
						update_post_meta( $post_ID, 'wps_wc_autoresponder_product_opt_in_label', siar( $wooc_ar_autoresponder, 'opt_label' ) );
					}

					update_post_meta( $post_ID, 'wps_wc_autoresponder_product_opt_in_field', ( siar( $wooc_ar_autoresponder, 'opt_in' ) ? 'yes' : 'no' ) );
					update_post_meta( $post_ID, 'wps_wc_autoresponder_product_opt_in_checked', ( siar( $wooc_ar_autoresponder, 'is_opt_value' ) ? true : false ) );

					// Lists
					foreach ( array( 'mailchimp', 'icontact', 'infusionsoft', 'constant_contact', 'campaign_monitor', 'vertical_response', 'getresponse', 'aweber', 'send_reach', 'active_campaign', 'mailpoet', 'mymail', 'mailster', 'wysija' ) as $autoresponder ) {
						if ( siar( $wooc_ar_autoresponder, $autoresponder . '_list' ) ) {
							update_post_meta( $post_ID, 'wps_wc_autoresponder_product_' . $autoresponder . '_list', siar( $wooc_ar_autoresponder, $autoresponder . '_list' ) );
						}

						if ( 'active_campaign' === $autoresponder && siar( $wooc_ar_autoresponder, $autoresponder . '_tags' ) ) {
							update_post_meta( $post_ID, 'wps_wc_autoresponder_product_' . $autoresponder . '_tags', siar( $wooc_ar_autoresponder, $autoresponder . '_tags' ) );
						}
					}
				}
			}
		}

		// General Settings
		$wooc_ar_options = get_option( 'wooc_ar_options' );

		if ( ! is_array( $wooc_ar_options ) ) {
			$wooc_ar_options = maybe_unserialize( $wooc_ar_options );
		}

		$subscribe_upon = siar( $wooc_ar_options, 'subscribe_at' );
		if ( $subscribe_upon ) {
			if ( 'order_proccessing' === $subscribe_upon ) {
				$subscribe_upon = 'payment_complete';
			}

			update_option( 'wps_wc_autoresponder_general_subscribe_upon', $subscribe_upon );
		}

		if ( siar( $wooc_ar_options, 'opt_in_label' ) ) {
			update_option( 'wps_wc_autoresponder_general_opt_in_label', siar( $wooc_ar_options, 'opt_in_label' ) );
		}

		$subscribe_to = siar( $wooc_ar_options, 'subscribe_to' );
		if ( 'mainlist' === $subscribe_to ) {
			$subscribe_to = 'global_list';
		} elseif ( 'productlist' === $subscribe_to ) {
			$subscribe_to = 'product_list';
		} else {
			$subscribe_to = 'both';
		}

		update_option( 'wps_wc_autoresponder_general_subscribe_to', $subscribe_to );
		update_option( 'wps_wc_autoresponder_general_opt_in_field', ( siar( $wooc_ar_options, 'opt_in' ) ? 'yes' : 'no' ) );
		update_option( 'wps_wc_autoresponder_general_opt_in_checked', ( siar( $wooc_ar_options, 'opt_in_value' ) ? 'yes' : 'no' ) );

		$options = array( 'mailchimp', 'aweber', 'icontact', 'infusionsoft', 'constant_contact', 'campaign_monitor', 'vertical_response', 'getresponse', 'send_reach', 'active_campaign', 'mailpoet', 'mymail', 'mailster', 'wysija' );

		foreach ( $options as $option ) {
			update_option( 'wps_wc_autoresponder_' . $option . '_enable', ( siars( $wooc_ar_options, $option . '/enable' ) ? 'yes' : 'no' ) );

			if ( siars( $wooc_ar_options, $option . '/list' ) ) {
				update_option( 'wps_wc_autoresponder_general_' . $option . '_list', siars( $wooc_ar_options, $option . '/list' ) );
			}

			if ( $option === 'mailchimp' ) {
				update_option( 'wps_wc_autoresponder_mailchimp_api_key', siars( $wooc_ar_options, 'mailchimp/api_key' ) );

				$mailchimp_data = get_option( 'wooc_ar_mailchimp' );

				if ( empty( $mailchimp_data ) ) {
					continue;
				}

				if ( ! is_array( $mailchimp_data ) ) {
					$mailchimp_data = maybe_unserialize( $mailchimp_data );
				}

				update_option( 'wps_wc_autoresponder_mailchimp_is_connected', ( siar( $mailchimp_data, 'is_connected' ) ? 'yes' : 'no' ) );

				if ( siar( $mailchimp_data, 'is_connected' ) ) {
					$lists = array();
					if ( siar( $mailchimp_data, 'lists' ) ) {
						foreach ( siar( $mailchimp_data, 'lists' ) as $list ) {
							if ( isset( $list->id ) && isset( $list->name ) ) {
								$lists[ $list->id ] = $list->name;
							}
						}
					}

					update_option( 'wps_wc_autoresponder_mailchimp_lists', $lists );
				}
			} elseif ( $option === 'aweber' ) {
				update_option( 'wps_wc_autoresponder_aweber_authorization_code', siars( $wooc_ar_options, 'aweber/api_key' ) );

				$aweber_data = get_option( 'wooc_ar_aweber' );

				if ( empty( $aweber_data ) ) {
					continue;
				}

				if ( ! is_array( $aweber_data ) ) {
					$aweber_data = maybe_unserialize( $aweber_data );
				}

				update_option( 'wps_wc_autoresponder_aweber_is_connected', ( siar( $aweber_data, 'is_connected' ) ? 'yes' : 'no' ) );

				if ( siar( $aweber_data, 'is_connected' ) ) {
					update_option( 'wps_wc_autoresponder_aweber_consumer_key', siar( $aweber_data, 'consumerKey' ) );
					update_option( 'wps_wc_autoresponder_aweber_consumer_secret', siar( $aweber_data, 'consumerSecret' ) );
					update_option( 'wps_wc_autoresponder_aweber_access_key', siar( $aweber_data, 'accessKey' ) );
					update_option( 'wps_wc_autoresponder_aweber_access_secret', siar( $aweber_data, 'accessSecret' ) );

					$lists = array();
					if ( siar( $aweber_data, 'lists' ) ) {
						foreach ( siar( $aweber_data, 'lists' ) as $list ) {
							if ( isset( $list['id'] ) && isset( $list['name'] ) ) {
								$lists[ $list['id'] ] = $list['name'];
							}
						}
					}

					update_option( 'wps_wc_autoresponder_aweber_lists', $lists );
				}
			} elseif ( $option === 'getresponse' ) {
				update_option( 'wps_wc_autoresponder_getresponse_api_key', siars( $wooc_ar_options, 'getresponse/api_key' ) );

				$getresponse_data = get_option( 'wooc_ar_getresponse' );

				if ( empty( $getresponse_data ) ) {
					continue;
				}

				if ( ! is_array( $getresponse_data ) ) {
					$getresponse_data = maybe_unserialize( $getresponse_data );
				}

				update_option( 'wps_wc_autoresponder_getresponse_is_connected', ( siar( $getresponse_data, 'is_connected' ) ? 'yes' : 'no' ) );

				if ( siar( $getresponse_data, 'is_connected' ) ) {
					$lists = array();
					if ( siar( $getresponse_data, 'lists' ) ) {
						foreach ( siar( $getresponse_data, 'lists' ) as $list_id => $list ) {
							$list = (array) $list;
							if ( isset( $list_id ) && isset( $list['name'] ) ) {
								$lists[ $list_id ] = $list['name'];
							}
						}
					}

					update_option( 'wps_wc_autoresponder_getresponse_lists', $lists );
				}
			} elseif ( $option === 'icontact' ) {
				update_option( 'wps_wc_autoresponder_icontact_api_app_id', siars( $wooc_ar_options, 'icontact/api_key' ) );
				update_option( 'wps_wc_autoresponder_icontact_api_username', siars( $wooc_ar_options, 'icontact/username' ) );
				update_option( 'wps_wc_autoresponder_icontact_api_password', siars( $wooc_ar_options, 'icontact/password' ) );
				update_option( 'wps_wc_autoresponder_icontact_pro', ( siars( $wooc_ar_options, 'icontact/version' ) ? 'yes' : 'no' ) );
				update_option( 'wps_wc_autoresponder_icontact_company_id', siars( $wooc_ar_options, 'icontact/companyid' ) );
				update_option( 'wps_wc_autoresponder_icontact_profile_id', siars( $wooc_ar_options, 'icontact/profileid' ) );

				$icontact_data = get_option( 'wooc_ar_icontact' );

				if ( empty( $icontact_data ) ) {
					continue;
				}

				if ( ! is_array( $icontact_data ) ) {
					$icontact_data = maybe_unserialize( $icontact_data );
				}

				update_option( 'wps_wc_autoresponder_icontact_is_connected', ( siar( $icontact_data, 'is_connected' ) ? 'yes' : 'no' ) );

				if ( siar( $icontact_data, 'is_connected' ) ) {
					$lists = array();
					if ( siar( $icontact_data, 'lists' ) ) {
						foreach ( siar( $icontact_data, 'lists' ) as $list ) {
							if ( isset( $list->listId ) && isset( $list->name ) ) {
								$lists[ $list->listId ] = $list->name;
							}
						}
					}

					update_option( 'wps_wc_autoresponder_icontact_lists', $lists );
				}
			} elseif ( $option === 'infusionsoft' ) {
				update_option( 'wps_wc_autoresponder_infusionsoft_api_key', siars( $wooc_ar_options, 'infusionsoft/api_key' ) );
				update_option( 'wps_wc_autoresponder_infusionsoft_application_name', siars( $wooc_ar_options, 'infusionsoft/app_name' ) );

				$infusionsoft_data = get_option( 'wooc_ar_infusionsoft' );

				if ( empty( $infusionsoft_data ) ) {
					continue;
				}

				if ( ! is_array( $infusionsoft_data ) ) {
					$infusionsoft_data = maybe_unserialize( $infusionsoft_data );
				}

				update_option( 'wps_wc_autoresponder_infusionsoft_is_connected', ( siar( $infusionsoft_data, 'is_connected' ) ? 'yes' : 'no' ) );

				if ( siar( $infusionsoft_data, 'is_connected' ) ) {
					$lists = array();
					if ( siar( $infusionsoft_data, 'lists' ) ) {
						foreach ( siar( $infusionsoft_data, 'lists' ) as $list ) {
							if ( isset( $list['Id'] ) && isset( $list['Name'] ) ) {
								$lists[ $list['Id'] ] = $list['Name'];
							}
						}
					}

					update_option( 'wps_wc_autoresponder_infusionsoft_lists', $lists );
				}
			} elseif ( $option === 'constant_contact' ) {
				update_option( 'wps_wc_autoresponder_constant_contact_api_key', siars( $wooc_ar_options, 'constant_contact/api_key' ) );
				update_option( 'wps_wc_autoresponder_constant_contact_access_token', siars( $wooc_ar_options, 'constant_contact/access_token' ) );

				$constant_contact_data = get_option( 'wooc_ar_constant_contact' );

				if ( empty( $constant_contact_data ) ) {
					continue;
				}

				if ( ! is_array( $constant_contact_data ) ) {
					$constant_contact_data = maybe_unserialize( $constant_contact_data );
				}

				update_option( 'wps_wc_autoresponder_constant_contact_is_connected', ( siar( $constant_contact_data, 'is_connected' ) ? 'yes' : 'no' ) );

				if ( siar( $constant_contact_data, 'is_connected' ) ) {
					$lists = array();
					if ( siar( $constant_contact_data, 'lists' ) ) {
						foreach ( siar( $constant_contact_data, 'lists' ) as $list ) {
							if ( isset( $list['id'] ) && isset( $list['name'] ) ) {
								$lists[ $list['id'] ] = $list['name'];
							}
						}
					}

					update_option( 'wps_wc_autoresponder_constant_contact_lists', $lists );
				}
			} elseif ( $option === 'campaign_monitor' ) {
				update_option( 'wps_wc_autoresponder_campaign_monitor_api_key', siars( $wooc_ar_options, 'campaign_monitor/api_key' ) );
				update_option( 'wps_wc_autoresponder_campaign_monitor_client_id', siars( $wooc_ar_options, 'campaign_monitor/client_id' ) );

				$campaign_monitor_data = get_option( 'wooc_ar_campaign_monitor' );

				if ( empty( $campaign_monitor_data ) ) {
					continue;
				}

				if ( ! is_array( $campaign_monitor_data ) ) {
					$campaign_monitor_data = maybe_unserialize( $campaign_monitor_data );
				}

				update_option( 'wps_wc_autoresponder_campaign_monitor_is_connected', ( siar( $campaign_monitor_data, 'is_connected' ) ? 'yes' : 'no' ) );

				if ( siar( $campaign_monitor_data, 'is_connected' ) ) {
					$lists = array();
					if ( siar( $campaign_monitor_data, 'lists' ) ) {
						foreach ( siar( $campaign_monitor_data, 'lists' ) as $list ) {
							if ( isset( $list->ListID ) && isset( $list->Name ) ) {
								$lists[ $list->ListID ] = $list->Name;
							}
						}
					}

					update_option( 'wps_wc_autoresponder_campaign_monitor_lists', $lists );
				}
			} elseif ( $option === 'vertical_response' ) {
				update_option( 'wps_wc_autoresponder_vertical_response_username', siars( $wooc_ar_options, 'vertical_response/username' ) );
				update_option( 'wps_wc_autoresponder_vertical_response_password', siars( $wooc_ar_options, 'vertical_response/password' ) );

				$vertical_response_data = get_option( 'wooc_ar_vertical_response' );

				if ( empty( $vertical_response_data ) ) {
					continue;
				}

				if ( ! is_array( $vertical_response_data ) ) {
					$vertical_response_data = maybe_unserialize( $vertical_response_data );
				}

				update_option( 'wps_wc_autoresponder_vertical_response_is_connected', ( siar( $vertical_response_data, 'is_connected' ) ? 'yes' : 'no' ) );

				if ( siar( $vertical_response_data, 'is_connected' ) ) {
					$lists = array();
					if ( siar( $vertical_response_data, 'lists' ) ) {
						foreach ( siar( $vertical_response_data, 'lists' ) as $list ) {
							if ( isset( $list->is_master ) && $list->is_master != 1 ) {
								if ( isset( $list->id ) && isset( $list->name ) ) {
									$lists[ $list->id ] = $list->name;
								}
							}
						}
					}

					update_option( 'wps_wc_autoresponder_vertical_response_lists', $lists );
				}
			} elseif ( $option === 'send_reach' ) {
				update_option( 'wps_wc_autoresponder_send_reach_api_key', siars( $wooc_ar_options, 'send_reach/username' ) );
				update_option( 'wps_wc_autoresponder_send_reach_api_secret', siars( $wooc_ar_options, 'send_reach/password' ) );
				update_option( 'wps_wc_autoresponder_send_reach_user_id', siars( $wooc_ar_options, 'send_reach/client_id' ) );
				update_option( 'wps_wc_autoresponder_send_reach_v3', ( siars( $wooc_ar_options, 'send_reach/version' ) ? 'yes' : 'no' ) );

				$send_reach_data = get_option( 'wooc_ar_send_reach' );

				if ( empty( $send_reach_data ) ) {
					continue;
				}

				if ( ! is_array( $send_reach_data ) ) {
					$send_reach_data = maybe_unserialize( $send_reach_data );
				}

				update_option( 'wps_wc_autoresponder_send_reach_is_connected', ( siar( $send_reach_data, 'is_connected' ) ? 'yes' : 'no' ) );

				if ( siar( $send_reach_data, 'is_connected' ) ) {
					$lists = array();
					if ( siar( $send_reach_data, 'lists' ) ) {
						foreach ( siar( $send_reach_data, 'lists' ) as $list ) {
							if ( isset( $list['id'] ) && isset( $list['name'] ) ) {
								$lists[ $list['id'] ] = $list['name'];
							}
						}
					}

					update_option( 'wps_wc_autoresponder_send_reach_lists', $lists );
				}
			} elseif ( $option === 'active_campaign' ) {
				update_option( 'wps_wc_autoresponder_active_campaign_api_url', siars( $wooc_ar_options, 'active_campaign/username' ) );
				update_option( 'wps_wc_autoresponder_active_campaign_api_secret', siars( $wooc_ar_options, 'active_campaign/api_key' ) );

				if ( siars( $wooc_ar_options, 'active_campaign/tags' ) ) {
					update_option( 'wps_wc_autoresponder_general_active_campaign_tags', siars( $wooc_ar_options, 'active_campaign/tags' ) );
				}

				$active_campaign_data = get_option( 'wooc_ar_active_campaign' );

				if ( empty( $active_campaign_data ) ) {
					continue;
				}

				if ( ! is_array( $active_campaign_data ) ) {
					$active_campaign_data = maybe_unserialize( $active_campaign_data );
				}

				update_option( 'wps_wc_autoresponder_active_campaign_is_connected', ( siar( $active_campaign_data, 'is_connected' ) ? 'yes' : 'no' ) );

				if ( siar( $active_campaign_data, 'is_connected' ) ) {
					$lists = array();
					if ( siar( $active_campaign_data, 'lists' ) ) {
						foreach ( siar( $active_campaign_data, 'lists' ) as $list ) {
							if ( isset( $list['id'] ) && isset( $list['name'] ) ) {
								$lists[ $list['id'] ] = $list['name'];
							}
						}
					}

					update_option( 'wps_wc_autoresponder_active_campaign_lists', $lists );
				}
			}
		}

		// Delete legacy data
		delete_option( 'wooc_ar_version' );
		delete_option( 'wooc_ar_options' );
		delete_option( 'wooc_ar_mailchimp' );
		delete_option( 'wooc_ar_aweber' );
		delete_option( 'wooc_ar_icontact' );
		delete_option( 'wooc_ar_infusionsoft' );
		delete_option( 'wooc_ar_constant_contact' );
		delete_option( 'wooc_ar_campaign_monitor' );
		delete_option( 'wooc_ar_vertical_response' );
		delete_option( 'wooc_ar_send_reach' );
		delete_option( 'wooc_ar_active_campaign' );
		delete_option( 'wooc_ar_getresponse' );
	}

	public function validate_purchase( $current_section ) {
		if ( 'license' !== $current_section ) {
			return;
		}

		if ( empty( sipost( 'wps_wc_autoresponder_license_key' ) ) ) {
			update_option( 'wps_wc_autoresponder_is_license_valid', false );
			return;
		}

		$response = wp_remote_post(
			'https://wpstriker.com/?page=wps_vpc',
			array(
				'method'      => 'POST',
				'timeout'     => 15,
				'redirection' => 5,
				'httpversion' => '1.1',
				'sslverify'   => false,
				'blocking'    => true,
				'body'        => array(
					'code' => sipost( 'wps_wc_autoresponder_license_key' ),
					'url'  => site_url(),
				),
			)
		);

		$purchase = false;

		if ( 200 === wp_remote_retrieve_response_code( $response ) ) {
			$response = wp_remote_retrieve_body( $response );
			$purchase = $response ? json_decode( $response ) : false;

			delete_site_transient( 'update_plugins' );
		}

		if ( ! ( $purchase && siobj( $purchase, 'is_valid' ) ) ) {
			WC_Admin_Settings::add_error( esc_html__( 'Invalid purchase code. Please check purchase code and try again.', 'wps-woocommerce-autoresponder' ) );
		}

		update_option( 'wps_wc_autoresponder_is_license_valid', $purchase && siobj( $purchase, 'is_valid' ) );
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WC_Autoresponder_Plugin_Update() {
	return WPS_WC_Autoresponder_Plugin_Update::get_instance();
}

$GLOBALS['WPS_WC_Autoresponder_Plugin_Update'] = WPS_WC_Autoresponder_Plugin_Update();
