<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( class_exists( 'WPS_WC_Autoresponder_Settings', false ) ) {
	return new WPS_WC_Autoresponder_Settings();
}

class WPS_WC_Autoresponder_Settings extends WC_Settings_Page {

	public function __construct() {
		$this->id    = 'wps_wc_autoresponder';
		$this->label = esc_html__( 'WooCommerce Autoresponder', 'wps-woocommerce-autoresponder' );

		parent::__construct();

		add_action( 'woocommerce_admin_field_status', array( $this, 'output_status_field' ), 20, 1 );
		add_action( 'woocommerce_admin_field_general_info_lists', array( $this, 'output_general_info_lists_field' ), 20, 1 );
	}

	protected function get_own_sections() {
		$sections = array(
			''                  => esc_html__( 'General Settings', 'wps-woocommerce-autoresponder' ),
			'license'           => esc_html__( 'General Info & License', 'wps-woocommerce-autoresponder' ),
			'mailchimp'         => esc_html__( 'Mailchimp', 'wps-woocommerce-autoresponder' ),
			'aweber'            => esc_html__( 'Aweber', 'wps-woocommerce-autoresponder' ),
			'getresponse'       => esc_html__( 'GetResponse', 'wps-woocommerce-autoresponder' ),
			'icontact'          => esc_html__( 'iContact', 'wps-woocommerce-autoresponder' ),
			'infusionsoft'      => esc_html__( 'Infusionsoft', 'wps-woocommerce-autoresponder' ),
			'constant_contact'  => esc_html__( 'Constant Contact', 'wps-woocommerce-autoresponder' ),
			'campaign_monitor'  => esc_html__( 'Campaign Monitor', 'wps-woocommerce-autoresponder' ),
			'vertical_response' => esc_html__( 'VerticalResponse', 'wps-woocommerce-autoresponder' ),
			'send_reach'        => esc_html__( 'SendReach', 'wps-woocommerce-autoresponder' ),
			'active_campaign'   => esc_html__( 'ActiveCampaign', 'wps-woocommerce-autoresponder' ),
			'sendinblue'        => esc_html__( 'Sendinblue', 'wps-woocommerce-autoresponder' ),
			'convertkit'        => esc_html__( 'ConvertKit', 'wps-woocommerce-autoresponder' ),
		);

		if ( WPS_WC_Autoresponder_Helper()->is_mymail_support() ) {
			$sections['mymail'] = esc_html__( 'MyMail', 'wps-woocommerce-autoresponder' );
		}

		if ( WPS_WC_Autoresponder_Helper()->is_mailster_support() ) {
			$sections['mailster'] = esc_html__( 'Mailster', 'wps-woocommerce-autoresponder' );
		}

		if ( WPS_WC_Autoresponder_Helper()->is_wysija_support() ) {
			$sections['wysija'] = esc_html__( 'Mailpoet (Wysija)', 'wps-woocommerce-autoresponder' );
		}

		if ( WPS_WC_Autoresponder_Helper()->is_mailpoet_support() ) {
			$sections['mailpoet'] = esc_html__( 'Mailpoet (v3)', 'wps-woocommerce-autoresponder' );
		}

		return apply_filters( 'wps_wc_autoresponder_settings_page_sections', $sections );
	}

	protected function get_settings_for_default_section() {
		$settings = array(
			array(
				'title' => 'General Settings',
				'type'  => 'title',
				'desc'  => esc_html__( 'Please visit General Info & License tab to get familiar with this plugin.', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_general_options',
			),
			array(
				'title'    => esc_html__( 'Subscribe customers to', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_subscribe_to',
				'type'     => 'radio',
				'default'  => 'global_list',
				'options'  => array(
					'global_list'  => esc_html__( 'General list (apply to order)', 'wps-woocommerce-autoresponder' ),
					'product_list' => esc_html__( 'Product list (apply to certain product, go to specific product edit page and select list)', 'wps-woocommerce-autoresponder' ),
					'both'         => esc_html__( 'Both general list and product list', 'wps-woocommerce-autoresponder' ),
				),
				'desc_tip' => true,
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Subscribe customers upon', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_subscribe_upon',
				'type'     => 'select',
				'default'  => 'order_created',
				'options'  => array(
					'order_created'    => esc_html__( 'Order created (Before Payment)', 'wps-woocommerce-autoresponder' ),
					'payment_complete' => esc_html__( 'Payment completed', 'wps-woocommerce-autoresponder' ),
					'order_processing' => esc_html__( 'Order processing', 'wps-woocommerce-autoresponder' ),
					'order_completed'  => esc_html__( 'Order completed', 'wps-woocommerce-autoresponder' ),
				),
				'class'    => 'wc-enhanced-select',
				'desc_tip' => true,
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Opt-In field', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_opt_in_field',
				'type'     => 'radio',
				'options'  => array(
					'no'  => esc_html__( 'No, do not display the opt-in field, this will subscribe to the customer to list(s) without confirmation', 'wps-woocommerce-autoresponder' ),
					'yes' => esc_html__( 'Yes, display the opt-in field (confirmation checkbox in checkout order page), this will subscribe to customers only if they confirm the opt-in field', 'wps-woocommerce-autoresponder' ),
				),
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Opt-In field label', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Opt-In field label displayed next to the opt-in checkbox in checkout form', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_opt_in_label',
				'type'     => 'text',
				'default'  => esc_html__( 'Subscribe to the newsletter', 'wps-woocommerce-autoresponder' ),
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Opt-In field placement', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_opt_in_place',
				'type'     => 'select',
				'default'  => 'billing',
				'options'  => array(
					'billing' => esc_html__( 'Inside billing fields', 'wps-woocommerce-autoresponder' ),
					'order'   => esc_html__( 'Inside additional fields', 'wps-woocommerce-autoresponder' ),
				),
				'class'    => 'wc-enhanced-select',
				'desc_tip' => true,
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Opt-In checkbox value', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable this to the opt-in checkbox field checked by default', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_opt_in_checked',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_general_options',
			),
		);

		$settings[] = array(
			'title' => 'General list',
			'type'  => 'title',
			'desc'  => 'All enabled and configured autoresponders list(s) will be available below.',
			'id'    => 'wps_wc_autoresponder_general_lists',
		);

		$settings = $this->get_global_list_setttings( $settings );

		$settings[] = array(
			'type' => 'sectionend',
			'id'   => 'wps_wc_autoresponder_general_lists',
		);

		return apply_filters( 'wps_wc_autoresponder_default_settings', $settings );
	}

	public function get_global_list_setttings( $settings ) {
		if ( 'yes' === get_option( 'wps_wc_autoresponder_mailchimp_enable', 'no' ) && 'yes' === get_option( 'wps_wc_autoresponder_mailchimp_is_connected', 'no' ) ) {
			$mailchimp_lists = get_option( 'wps_wc_autoresponder_mailchimp_lists', array() );
			$mailchimp_lists = array( '' => esc_html__( '-- Select list --', 'wps-woocommerce-autoresponder' ) ) + (array) $mailchimp_lists;

			$settings[] = array(
				'title'    => esc_html__( 'Mailchimp list', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_mailchimp_list',
				'type'     => 'select',
				'options'  => $mailchimp_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);

			$settings[] = array(
				'title'    => esc_html__( 'Mailchimp tags', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'If you want multiple tags then enter comma-separated values.', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_mailchimp_tags',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_aweber_enable', 'no' ) && 'yes' === get_option( 'wps_wc_autoresponder_aweber_is_connected', 'no' ) ) {
			$aweber_lists = get_option( 'wps_wc_autoresponder_aweber_lists', array() );
			$aweber_lists = array( '' => esc_html__( '-- Select list --', 'wps-woocommerce-autoresponder' ) ) + (array) $aweber_lists;

			$settings[] = array(
				'title'    => esc_html__( 'Aweber list', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_aweber_list',
				'type'     => 'select',
				'options'  => $aweber_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_getresponse_enable', 'no' ) && 'yes' === get_option( 'wps_wc_autoresponder_getresponse_is_connected', 'no' ) ) {
			$getresponse_lists = get_option( 'wps_wc_autoresponder_getresponse_lists', array() );
			$getresponse_lists = array( '' => esc_html__( '-- Select campaign --', 'wps-woocommerce-autoresponder' ) ) + (array) $getresponse_lists;

			$settings[] = array(
				'title'    => esc_html__( 'GetResponse campaign', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_getresponse_list',
				'type'     => 'select',
				'options'  => $getresponse_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_icontact_enable', 'no' ) && 'yes' === get_option( 'wps_wc_autoresponder_icontact_is_connected', 'no' ) ) {
			$icontact_lists = get_option( 'wps_wc_autoresponder_icontact_lists', array() );
			$icontact_lists = array( '' => esc_html__( '-- Select list --', 'wps-woocommerce-autoresponder' ) ) + (array) $icontact_lists;

			$settings[] = array(
				'title'    => esc_html__( 'iContact list', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_icontact_list',
				'type'     => 'select',
				'options'  => $icontact_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_infusionsoft_enable', 'no' ) && 'yes' === get_option( 'wps_wc_autoresponder_infusionsoft_is_connected', 'no' ) ) {
			$infusionsoft_lists = get_option( 'wps_wc_autoresponder_infusionsoft_lists', array() );
			$infusionsoft_lists = array( '' => esc_html__( '-- Select campaign --', 'wps-woocommerce-autoresponder' ) ) + (array) $infusionsoft_lists;

			$settings[] = array(
				'title'    => esc_html__( 'Infusionsoft campaign', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_infusionsoft_list',
				'type'     => 'select',
				'options'  => $infusionsoft_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_constant_contact_enable', 'no' ) && 'yes' === get_option( 'wps_wc_autoresponder_constant_contact_is_connected', 'no' ) ) {
			$constant_contact_lists = get_option( 'wps_wc_autoresponder_constant_contact_lists', array() );
			$constant_contact_lists = array( '' => esc_html__( '-- Select list --', 'wps-woocommerce-autoresponder' ) ) + (array) $constant_contact_lists;

			$settings[] = array(
				'title'    => esc_html__( 'Constant Contact list', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_constant_contact_list',
				'type'     => 'select',
				'options'  => $constant_contact_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_campaign_monitor_enable', 'no' ) && 'yes' === get_option( 'wps_wc_autoresponder_campaign_monitor_is_connected', 'no' ) ) {
			$campaign_monitor_lists = get_option( 'wps_wc_autoresponder_campaign_monitor_lists', array() );
			$campaign_monitor_lists = array( '' => esc_html__( '-- Select list --', 'wps-woocommerce-autoresponder' ) ) + (array) $campaign_monitor_lists;

			$settings[] = array(
				'title'    => esc_html__( 'Campaign Monitor list', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_campaign_monitor_list',
				'type'     => 'select',
				'options'  => $campaign_monitor_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_vertical_response_enable', 'no' ) && 'yes' === get_option( 'wps_wc_autoresponder_vertical_response_is_connected', 'no' ) ) {
			$vertical_response_lists = get_option( 'wps_wc_autoresponder_vertical_response_lists', array() );
			$vertical_response_lists = array( '' => esc_html__( '-- Select list --', 'wps-woocommerce-autoresponder' ) ) + (array) $vertical_response_lists;

			$settings[] = array(
				'title'    => esc_html__( 'VerticalResponse list', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_vertical_response_list',
				'type'     => 'select',
				'options'  => $vertical_response_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_send_reach_enable', 'no' ) && 'yes' === get_option( 'wps_wc_autoresponder_send_reach_is_connected', 'no' ) ) {
			$send_reach_lists = get_option( 'wps_wc_autoresponder_send_reach_lists', array() );
			$send_reach_lists = array( '' => esc_html__( '-- Select list --', 'wps-woocommerce-autoresponder' ) ) + (array) $send_reach_lists;

			$settings[] = array(
				'title'    => esc_html__( 'SendReach list', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_send_reach_list',
				'type'     => 'select',
				'options'  => $send_reach_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_active_campaign_enable', 'no' ) && 'yes' === get_option( 'wps_wc_autoresponder_active_campaign_is_connected', 'no' ) ) {
			$active_campaign_lists = get_option( 'wps_wc_autoresponder_active_campaign_lists', array() );
			$active_campaign_lists = array( '' => esc_html__( '-- Select list --', 'wps-woocommerce-autoresponder' ) ) + (array) $active_campaign_lists;

			$settings[] = array(
				'title'    => esc_html__( 'ActiveCampaign list', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_active_campaign_list',
				'type'     => 'select',
				'options'  => $active_campaign_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);

			$settings[] = array(
				'title'    => esc_html__( 'ActiveCampaign tags', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'If you want multiple tags then enter comma-separated values.', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_active_campaign_tags',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_sendinblue_enable', 'no' ) && 'yes' === get_option( 'wps_wc_autoresponder_sendinblue_is_connected', 'no' ) ) {
			$sendinblue_lists = get_option( 'wps_wc_autoresponder_sendinblue_lists', array() );
			$sendinblue_lists = array( '' => esc_html__( '-- Select list --', 'wps-woocommerce-autoresponder' ) ) + (array) $sendinblue_lists;

			$settings[] = array(
				'title'    => esc_html__( 'Sendinblue list', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_sendinblue_list',
				'type'     => 'select',
				'options'  => $sendinblue_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_convertkit_enable', 'no' ) && 'yes' === get_option( 'wps_wc_autoresponder_convertkit_is_connected', 'no' ) ) {
			$convertkit_lists = get_option( 'wps_wc_autoresponder_convertkit_lists', array() );
			$convertkit_lists = array( '' => esc_html__( '-- Select form --', 'wps-woocommerce-autoresponder' ) ) + (array) $convertkit_lists;

			$settings[] = array(
				'title'    => esc_html__( 'ConvertKit form', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_convertkit_list',
				'type'     => 'select',
				'options'  => $convertkit_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);

			$convertkit_sequences = get_option( 'wps_wc_autoresponder_convertkit_sequences', array() );
			$convertkit_sequences = array( '' => esc_html__( '-- Select sequence --', 'wps-woocommerce-autoresponder' ) ) + (array) $convertkit_sequences;

			$settings[] = array(
				'title'    => esc_html__( 'ConvertKit sequence', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_convertkit_sequence',
				'type'     => 'select',
				'options'  => $convertkit_sequences,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_mymail_enable', 'no' ) && WPS_WC_Autoresponder_Helper()->is_mymail_support() ) {
			$mymail_lists = WPS_WC_Autoresponder_Helper()->get_mymail_data();
			$mymail_lists = array( '' => esc_html__( '-- Select list --', 'wps-woocommerce-autoresponder' ) ) + (array) $mymail_lists;

			$settings[] = array(
				'title'    => esc_html__( 'MyMail list', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_mymail_list',
				'type'     => 'select',
				'options'  => $mymail_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_mailster_enable', 'no' ) && WPS_WC_Autoresponder_Helper()->is_mailster_support() ) {
			$mailster_lists = WPS_WC_Autoresponder_Helper()->get_mailster_data();
			$mailster_lists = array( '' => esc_html__( '-- Select list --', 'wps-woocommerce-autoresponder' ) ) + (array) $mailster_lists;

			$settings[] = array(
				'title'    => esc_html__( 'Mailster list', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_mailster_list',
				'type'     => 'select',
				'options'  => $mailster_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_wysija_enable', 'no' ) && WPS_WC_Autoresponder_Helper()->is_wysija_support() ) {
			$wysija_lists = WPS_WC_Autoresponder_Helper()->get_wysija_data();
			$wysija_lists = array( '' => esc_html__( '-- Select list --', 'wps-woocommerce-autoresponder' ) ) + (array) $wysija_lists;

			$settings[] = array(
				'title'    => esc_html__( 'Mailpoet (Wysija) list', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_wysija_list',
				'type'     => 'select',
				'options'  => $wysija_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_mailpoet_enable', 'no' ) && WPS_WC_Autoresponder_Helper()->is_mailpoet_support() ) {
			$mailpoet_lists = WPS_WC_Autoresponder_Helper()->get_mailpoet_data();
			$mailpoet_lists = array( '' => esc_html__( '-- Select list --', 'wps-woocommerce-autoresponder' ) ) + (array) $mailpoet_lists;

			$settings[] = array(
				'title'    => esc_html__( 'Mailpoet (v3) list', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_general_mailpoet_list',
				'type'     => 'select',
				'options'  => $mailpoet_lists,
				'class'    => 'wc-enhanced-select',
				'autoload' => false,
			);
		}

		return $settings;
	}

	protected function get_settings_for_license_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'General Info', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => '',
				'id'    => 'wps_wc_autoresponder_general_info_options',
			),
			array(
				'id'   => 'wps_wc_autoresponder_general_info_lists',
				'type' => 'general_info_lists',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_general_info_options',
			),
			array(
				'title' => esc_html__( 'Plugin', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => '',
				'id'    => 'wps_wc_autoresponder_plugin_options',
			),
			array(
				'title'      => esc_html__( 'Version', 'wps-woocommerce-autoresponder' ),
				'id'         => 'wps_wc_autoresponder_plugin_version',
				'value'      => WPS_WOOCOMMERCE_AUTORESPONDER_VERSION,
				'is_version' => true,
				'type'       => 'status',
			),
			array(
				'title'    => esc_html__( 'When uninstall', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Delete Plugin Settings', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_uninstall_settings',
				'type'     => 'checkbox',
				'default'  => 'no',
				'desc_tip' => esc_html__( 'If this field checked it will delete all settings data when plugin is uninstalled from WordPress and this action can\'t be undone.', 'wps-woocommerce-autoresponder' ),
				'autoload' => false,
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_debug_options',
			),
			array(
				'title' => esc_html__( 'Debug', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => '',
				'id'    => 'wps_wc_autoresponder_debug',
			),
			array(
				'title'    => esc_html__( 'Debugging', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable debug options', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_debug',
				'type'     => 'checkbox',
				'default'  => 'no',
				'desc_tip' => esc_html__( 'Save debug messages to the WooCommerce System Status log.', 'wps-woocommerce-autoresponder' ),
				'autoload' => false,
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_debug_options',
			),
			array(
				'title' => esc_html__( 'License', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => '',
				'id'    => 'wps_wc_autoresponder_license_options',
			),
			array(
				'title'    => esc_html__( 'Purchase code', 'wps-woocommerce-autoresponder' ),
				'desc'     => sprintf(
					'%s <a href="%s" target="_blank">%s</a>',
					esc_html__( 'Please enter purchase code given by codecanyon. For more information, visit', 'wps-woocommerce-autoresponder' ),
					esc_url( 'https://help.market.envato.com/hc/en-us/articles/202822600-Where-Is-My-Purchase-Code-' ),
					esc_html__( 'this link.', 'wps-woocommerce-autoresponder' )
				),
				'id'       => 'wps_wc_autoresponder_license_key',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title'      => esc_html__( 'License status', 'wps-woocommerce-autoresponder' ),
				'id'         => 'wps_wc_autoresponder_license_status',
				'value'      => wc_string_to_bool( get_option( 'wps_wc_autoresponder_is_license_valid', 'no' ) ),
				'is_license' => true,
				'type'       => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_license_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_license_settings', $settings );
	}

	protected function get_settings_for_mailchimp_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'Mailchimp', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Once you connected and if you want to refresh list(s) then just save it again, and it will sync all list(s) again.', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_mailchimp_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable Mailchimp', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_mailchimp_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'API key', 'wps-woocommerce-autoresponder' ),
				'desc'     => sprintf(
					'%s <a target="_blank" href="%s">%s</a>',
					esc_html__( 'Enter API Key provided by mailchimp.', 'wps-woocommerce-autoresponder' ),
					esc_url( add_query_arg( 'mailchimp', 1, trailingslashit( WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL ) ) ),
					esc_html__( 'Read more', 'wps-woocommerce-autoresponder' )
				),
				'id'       => 'wps_wc_autoresponder_mailchimp_api_key',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_mailchimp_status',
				'value' => wc_string_to_bool( get_option( 'wps_wc_autoresponder_mailchimp_is_connected', 'no' ) ),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_mailchimp_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_mailchimp_settings', $settings );
	}

	protected function get_settings_for_aweber_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'Aweber', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Once you connected and if you want to refresh list(s) then just save it again, and it will sync all list(s) again.', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_aweber_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable Aweber', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_aweber_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Authorization Code', 'wps-woocommerce-autoresponder' ),
				'desc'     => sprintf(
					'%s <a target="_blank" href="%s">%s</a> %s',
					esc_html__( 'Enter authorization code provided by Aweber,', 'wps-woocommerce-autoresponder' ),
					esc_url( 'https://auth.aweber.com/1.0/oauth/authorize_app/80a53838' ),
					esc_html__( 'Click here to retrieve your authorization code.', 'wps-woocommerce-autoresponder' ),
					esc_html__( 'Once your authorization completed you will get a authorization code, then copy it and paste in above box.', 'wps-woocommerce-autoresponder' )
				),
				'id'       => 'wps_wc_autoresponder_aweber_authorization_code',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_aweber_status',
				'value' => wc_string_to_bool( get_option( 'wps_wc_autoresponder_aweber_is_connected', 'no' ) ),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_aweber_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_aweber_settings', $settings );
	}

	protected function get_settings_for_getresponse_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'GetResponse', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Once you connected and if you want to refresh campaign(s) then just save it again, and it will sync all campaign(s) again.', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_getresponse_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable getResponse', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_getresponse_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'API key', 'wps-woocommerce-autoresponder' ),
				'desc'     => sprintf(
					'%s <a target="_blank" href="%s">%s</a>',
					esc_html__( 'Enter API Key provided by getResponse.', 'wps-woocommerce-autoresponder' ),
					esc_url( add_query_arg( 'getresponse', 1, trailingslashit( WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL ) ) ),
					esc_html__( 'Read more', 'wps-woocommerce-autoresponder' )
				),
				'id'       => 'wps_wc_autoresponder_getresponse_api_key',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_getresponse_status',
				'value' => wc_string_to_bool( get_option( 'wps_wc_autoresponder_getresponse_is_connected', 'no' ) ),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_getresponse_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_getresponse_settings', $settings );
	}

	protected function get_settings_for_icontact_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'iContact', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Once you connected and if you want to refresh list(s) then just save it again, and it will sync all list(s) again.', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_icontact_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable iContact', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_icontact_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'API-AppId', 'wps-woocommerce-autoresponder' ),
				'desc'     => sprintf(
					'%s <a target="_blank" href="%s">%s</a>',
					esc_html__( 'Enter AppId provided by iContact.', 'wps-woocommerce-autoresponder' ),
					esc_url( add_query_arg( 'icontact', 1, trailingslashit( WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL ) ) ),
					esc_html__( 'Read more', 'wps-woocommerce-autoresponder' )
				),
				'id'       => 'wps_wc_autoresponder_icontact_api_app_id',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Username', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_icontact_api_username',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Password', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_icontact_api_password',
				'type'     => 'password',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'iContact pro', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Are you using iContact Pro?', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_icontact_pro',
				'type'     => 'checkbox',
				'default'  => 'no',
				'desc_tip' => sprintf(
					'%s <a target="_blank" href="%s">%s</a>',
					esc_html__( 'To know how to get credentials for iContact Pro visit', 'wps-woocommerce-autoresponder' ),
					esc_url( add_query_arg( 'icontactpro', 1, trailingslashit( WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL ) ) ),
					esc_html__( 'this link', 'wps-woocommerce-autoresponder' )
				),
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Company Id', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Need only if you are using iContact Pro', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_icontact_company_id',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Profile Id', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Need only if you are using iContact Pro', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_icontact_profile_id',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_icontact_status',
				'value' => wc_string_to_bool( get_option( 'wps_wc_autoresponder_icontact_is_connected', 'no' ) ),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_icontact_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_icontact_settings', $settings );
	}

	protected function get_settings_for_infusionsoft_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'Infusionsoft', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Once you connected and if you want to refresh campaign(s) then just save it again, and it will sync all campaign(s) again.', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_infusionsoft_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable Infusionsoft', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_infusionsoft_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'API Key', 'wps-woocommerce-autoresponder' ),
				'desc'     => sprintf(
					'%s <a target="_blank" href="%s">%s</a>',
					esc_html__( 'Enter API Key provided by Infusionsoft.', 'wps-woocommerce-autoresponder' ),
					esc_url( add_query_arg( 'infusionsoft', 1, trailingslashit( WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL ) ) ),
					esc_html__( 'Read more', 'wps-woocommerce-autoresponder' )
				),
				'id'       => 'wps_wc_autoresponder_infusionsoft_api_key',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Application name', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_infusionsoft_application_name',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_infusionsoft_status',
				'value' => wc_string_to_bool( get_option( 'wps_wc_autoresponder_infusionsoft_is_connected', 'no' ) ),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_infusionsoft_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_infusionsoft_settings', $settings );
	}

	protected function get_settings_for_constant_contact_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'Constant Contact', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Once you connected and if you want to refresh list(s) then just save it again, and it will sync all list(s) again.', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_constant_contact_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable Constant Contact', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_constant_contact_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'API Key', 'wps-woocommerce-autoresponder' ),
				'desc'     => sprintf(
					'%s <a target="_blank" href="%s">%s</a>',
					esc_html__( 'Enter API Key provided by Constant Contact.', 'wps-woocommerce-autoresponder' ),
					esc_url( add_query_arg( 'constant_contact', 1, trailingslashit( WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL ) ) ),
					esc_html__( 'Read more', 'wps-woocommerce-autoresponder' )
				),
				'id'       => 'wps_wc_autoresponder_constant_contact_api_key',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Access Token', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_constant_contact_access_token',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_constant_contact_status',
				'value' => wc_string_to_bool( get_option( 'wps_wc_autoresponder_constant_contact_is_connected', 'no' ) ),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_constant_contact_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_constant_contact_settings', $settings );
	}

	protected function get_settings_for_campaign_monitor_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'Campaign Monitor', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Once you connected and if you want to refresh list(s) then just save it again, and it will sync all list(s) again.', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_campaign_monitor_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable Campaign Monitor', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_campaign_monitor_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'API Key', 'wps-woocommerce-autoresponder' ),
				'desc'     => sprintf(
					'%s <a target="_blank" href="%s">%s</a>',
					esc_html__( 'Enter API Key provided by Campaign Monitor.', 'wps-woocommerce-autoresponder' ),
					esc_url( add_query_arg( 'campaign_monitor', 1, trailingslashit( WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL ) ) ),
					esc_html__( 'Read more', 'wps-woocommerce-autoresponder' )
				),
				'id'       => 'wps_wc_autoresponder_campaign_monitor_api_key',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Client ID', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_campaign_monitor_client_id',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_campaign_monitor_status',
				'value' => wc_string_to_bool( get_option( 'wps_wc_autoresponder_campaign_monitor_is_connected', 'no' ) ),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_campaign_monitor_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_campaign_monitor_settings', $settings );
	}

	protected function get_settings_for_vertical_response_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'VerticalResponse', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Once you connected and if you want to refresh list(s) then just save it again, and it will sync all list(s) again.', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_vertical_response_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable Vertical Response', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_vertical_response_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Username', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enter VerticalResponse username.', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_vertical_response_username',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Password', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_vertical_response_password',
				'desc'     => esc_html__( 'Enter VerticalResponse password.', 'wps-woocommerce-autoresponder' ),
				'type'     => 'password',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_vertical_response_status',
				'value' => wc_string_to_bool( get_option( 'wps_wc_autoresponder_vertical_response_is_connected', 'no' ) ),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_vertical_response_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_vertical_response_settings', $settings );
	}

	protected function get_settings_for_send_reach_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'SendReach', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Once you connected and if you want to refresh list(s) then just save it again, and it will sync all list(s) again.', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_send_reach_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable SendReach', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_send_reach_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'Version', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Are you using Sendreach V3?', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_send_reach_v3',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'API Key', 'wps-woocommerce-autoresponder' ),
				'desc'     => sprintf(
					'%s <a target="_blank" href="%s">%s</a>',
					esc_html__( 'Enter API Key provided by Sendreach.', 'wps-woocommerce-autoresponder' ),
					esc_url( add_query_arg( 'send_reach', 1, trailingslashit( WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL ) ) ),
					esc_html__( 'Read more', 'wps-woocommerce-autoresponder' )
				),
				'id'       => 'wps_wc_autoresponder_send_reach_api_key',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'API Secret', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_send_reach_api_secret',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'User ID', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_send_reach_user_id',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_send_reach_status',
				'value' => wc_string_to_bool( get_option( 'wps_wc_autoresponder_send_reach_is_connected', 'no' ) ),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_send_reach_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_send_reach_settings', $settings );
	}

	protected function get_settings_for_active_campaign_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'ActiveCampaign', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Once you connected and if you want to refresh list(s) then just save it again, and it will sync all list(s) again.', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_active_campaign_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable ActiveCampaign', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_active_campaign_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'API URL', 'wps-woocommerce-autoresponder' ),
				'desc'     => sprintf(
					'%s <a target="_blank" href="%s">%s</a>',
					esc_html__( 'Enter API URL provided by ActiveCampaign.', 'wps-woocommerce-autoresponder' ),
					esc_url( add_query_arg( 'active_campaign', 1, trailingslashit( WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL ) ) ),
					esc_html__( 'Read more', 'wps-woocommerce-autoresponder' )
				),
				'id'       => 'wps_wc_autoresponder_active_campaign_api_url',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'API Secret', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_active_campaign_api_secret',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_active_campaign_status',
				'value' => wc_string_to_bool( get_option( 'wps_wc_autoresponder_active_campaign_is_connected', 'no' ) ),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_active_campaign_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_active_campaign_settings', $settings );
	}

	protected function get_settings_for_sendinblue_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'Sendinblue', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Once you connected and if you want to refresh list(s) then just save it again, and it will sync all list(s) again.', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_sendinblue_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable Sendinblue', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_sendinblue_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'API Key', 'wps-woocommerce-autoresponder' ),
				'desc'     => sprintf(
					'%s <a target="_blank" href="%s">%s</a>',
					esc_html__( 'Enter API Key provided by Sendinblue.', 'wps-woocommerce-autoresponder' ),
					esc_url( add_query_arg( 'sendinblue', 1, trailingslashit( WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL ) ) ),
					esc_html__( 'Read more', 'wps-woocommerce-autoresponder' )
				),
				'id'       => 'wps_wc_autoresponder_sendinblue_api_key',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_sendinblue_status',
				'value' => wc_string_to_bool( get_option( 'wps_wc_autoresponder_sendinblue_is_connected', 'no' ) ),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_sendinblue_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_sendinblue_settings', $settings );
	}

	protected function get_settings_for_convertkit_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'ConvertKit', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Once you connected and if you want to refresh forms(s) and sequence(s) then just save it again, and it will sync all forms(s) and sequence(s) again.', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_convertkit_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable ConvertKit', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_convertkit_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title'    => esc_html__( 'API Key', 'wps-woocommerce-autoresponder' ),
				'desc'     => sprintf(
					'%s <a target="_blank" href="%s">%s</a>',
					esc_html__( 'Enter API Key provided by ConvertKit.', 'wps-woocommerce-autoresponder' ),
					esc_url( add_query_arg( 'convertkit', 1, trailingslashit( WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL ) ) ),
					esc_html__( 'Read more', 'wps-woocommerce-autoresponder' )
				),
				'id'       => 'wps_wc_autoresponder_convertkit_api_key',
				'type'     => 'text',
				'default'  => '',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_convertkit_status',
				'value' => wc_string_to_bool( get_option( 'wps_wc_autoresponder_convertkit_is_connected', 'no' ) ),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_convertkit_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_convertkit_settings', $settings );
	}

	protected function get_settings_for_mymail_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'MyMail', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => '',
				'id'    => 'wps_wc_autoresponder_mymail_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable MyMail', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_mymail_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_mymail_status',
				'value' => WPS_WC_Autoresponder_Helper()->is_mymail_support(),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_mymail_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_mymail_settings', $settings );
	}

	protected function get_settings_for_mailster_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'Mailster', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => '',
				'id'    => 'wps_wc_autoresponder_mailster_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable Mailster', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_mailster_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_mailster_status',
				'value' => WPS_WC_Autoresponder_Helper()->is_mailster_support(),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_mailster_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_mailster_settings', $settings );
	}

	protected function get_settings_for_wysija_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'Mailpoet (Wysija)', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => '',
				'id'    => 'wps_wc_autoresponder_wysija_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable Mailpoet (Wysija)', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_wysija_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_wysija_status',
				'value' => WPS_WC_Autoresponder_Helper()->is_wysija_support(),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_wysija_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_wysija_settings', $settings );
	}

	protected function get_settings_for_mailpoet_section() {
		$settings = array(
			array(
				'title' => esc_html__( 'MailPoet (v3)', 'wps-woocommerce-autoresponder' ),
				'type'  => 'title',
				'desc'  => '',
				'id'    => 'wps_wc_autoresponder_mailpoet_options',
			),
			array(
				'title'    => esc_html__( 'Enable/Disable', 'wps-woocommerce-autoresponder' ),
				'desc'     => esc_html__( 'Enable MailPoet (v3)', 'wps-woocommerce-autoresponder' ),
				'id'       => 'wps_wc_autoresponder_mailpoet_enable',
				'type'     => 'checkbox',
				'default'  => 'no',
				'autoload' => false,
			),
			array(
				'title' => esc_html__( 'Connection status', 'wps-woocommerce-autoresponder' ),
				'id'    => 'wps_wc_autoresponder_mailpoet_status',
				'value' => WPS_WC_Autoresponder_Helper()->is_mailpoet_support(),
				'type'  => 'status',
			),
			array(
				'type' => 'sectionend',
				'id'   => 'wps_wc_autoresponder_mailpoet_options',
			),
		);

		return apply_filters( 'wps_wc_autoresponder_mailpoet_settings', $settings );
	}

	public function output_status_field( $value ) {

		$description = '';

		if ( isset( $value['desc'] ) && ! empty( $value['desc'] ) ) {
			$description = $value['desc'];
			$description = '<p class="description">' . wp_kses_post( $description ) . '</p>';
		}

		?>
		<tr valign="top">
			<th scope="row" class="titledesc">
				<label for="<?php echo esc_attr( $value['id'] ); ?>"><?php echo esc_html( $value['title'] ); ?></label>
			</th>
			<td class="forminp forminp-<?php echo esc_attr( sanitize_title( $value['type'] ) ); ?>">
				<?php
				if ( siar( $value, 'is_version' ) ) {
					printf( '<strong>%s</strong>', ( isset( $value['value'] ) && $value['value'] ? esc_html( $value['value'] ) : '' ) ); // WPCS: XSS ok.
				} elseif ( siar( $value, 'is_license' ) ) {
					printf( '<strong>%s</strong>', ( isset( $value['value'] ) && $value['value'] ? esc_html__( 'Active', 'wps-woocommerce-autoresponder' ) : esc_html__( 'Not active', 'wps-woocommerce-autoresponder' ) ) );   // WPCS: XSS ok.
				} else {
					printf( '<strong>%s</strong>', ( isset( $value['value'] ) && $value['value'] ? esc_html__( 'Connected', 'wps-woocommerce-autoresponder' ) : esc_html__( 'Not connected', 'wps-woocommerce-autoresponder' ) ) ); // WPCS: XSS ok.
				}
				?>
				<?php echo $description; // WPCS: XSS ok. ?>
			</td>
		</tr>
		<?php
	}

	public function output_general_info_lists_field( $value ) {
		?>
		<tr valign="top">
			<td class="forminp forminp-<?php echo esc_attr( sanitize_title( $value['type'] ) ); ?>">
				<ol type="I">
					<li>
					<?php
						printf(
							'%s <a target="_blank" href="%s">%s</a>',
							esc_html__( 'Getting started with', 'wps-woocommerce-autoresponder' ),
							esc_url( WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL ),
							esc_html__( 'documentation', 'wps-woocommerce-autoresponder' )
						); // WPCS: XSS ok.
					?>
					</li>
					<li>
					<?php
						printf(
							'%s <a target="_blank" href="%s">%s</a>',
							esc_html__( 'Stuck with something? Get plugin ', 'wps-woocommerce-autoresponder' ),
							esc_url( WPS_WOOCOMMERCE_AUTORESPONDER_SUPPORT_URL ),
							esc_html__( 'premium support', 'wps-woocommerce-autoresponder' )
						); // WPCS: XSS ok.
					?>
					</li>
					<li><?php esc_html_e( 'We do not track any information from your site.', 'wps-woocommerce-autoresponder' ); ?></li>
					<li><?php esc_html_e( 'We do not send any credentials or any information to our site or server. All of your data stays in your server.', 'wps-woocommerce-autoresponder' ); ?></li>
					<li><?php esc_html_e( 'If you deactivate the plugin, then your settings will not be deleted from the database.', 'wps-woocommerce-autoresponder' ); ?></li>
					<li><?php esc_html_e( 'If you delete (uninstall) the plugin from WordPress, if you have chosen \'Delete Plugin Settings\' in below settings then settings will be deleted from database otherwise you only remove the plugin and its files.', 'wps-woocommerce-autoresponder' ); ?></li>
				</ul>
			</td>
		</tr>
		<?php
	}

	public function form_method( $method ) {
		return 'post';
	}

	public function save() {
		global $current_section;

		$this->save_settings_for_current_section();
		$this->do_update_options_action();

		do_action( 'wps_wc_autoresponder_after_save_settings_section', $current_section );
	}
}

return new WPS_WC_Autoresponder_Settings();
