<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WPS_WC_Autoresponder_Subscribe {

	public $autoresponders = array(
		'mailchimp',
		'getresponse',
		'aweber',
		'icontact',
		'infusionsoft',
		'constant_contact',
		'campaign_monitor',
		'vertical_response',
		'send_reach',
		'active_campaign',
		'sendinblue',
		'convertkit',
		'mymail',
		'mailster',
		'wysija',
		'mailpoet',
	);

	protected static $instance;

	public function __construct() {
		add_filter( 'woocommerce_checkout_fields', array( $this, 'add_opt_in_checkout_fields' ), 20, 1 );
		add_action( 'woocommerce_checkout_update_order_meta', array( $this, 'save_opt_in_checkout_fields' ), 20, 2 );
		add_action( 'woocommerce_checkout_order_created', array( $this, 'subscribe_upon_order_created' ), 20 );
		add_action( 'woocommerce_order_status_processing', array( $this, 'subscribe_upon_order_processing' ), 20 );
		add_action( 'woocommerce_order_status_completed', array( $this, 'subscribe_upon_order_completed' ), 20 );
		add_action( 'woocommerce_payment_complete', array( $this, 'subscribe_upon_payment_complete' ), 20 );

		if ( is_admin() ) {
			add_action( 'wps_wc_autoresponder_after_save_settings_section', array( $this, 'connect_autoresponder' ), 20, 1 );
		}
	}

	public function add_opt_in_checkout_fields( $fields ) {
		if ( 'yes' === get_option( 'wps_wc_autoresponder_general_opt_in_field', 'no' ) && in_array( get_option( 'wps_wc_autoresponder_general_subscribe_to', 'global_list' ), array( 'global_list', 'both' ) ) ) {
			$general_field = array(
				'label'   => esc_html( get_option( 'wps_wc_autoresponder_general_opt_in_label', esc_html__( 'Subscribe to the newsletter', 'wps-woocommerce-autoresponder' ) ) ),
				'type'    => 'checkbox',
				'class'   => array( 'form-row-wide' ),
				'default' => wc_string_to_bool( get_option( 'wps_wc_autoresponder_general_opt_in_checked', 'no' ) ),
			);

			if ( 'order' === get_option( 'wps_wc_autoresponder_general_opt_in_place', 'billing' ) ) {
				if ( isset( $fields['order'] ) && $fields['order'] ) {
					$fields['order']['wps_wc_autoresponder_optin'] = $general_field;
				} else {
					$fields['order'] = array( 'wps_wc_autoresponder_optin' => $general_field );
				}
			} else {
				if ( isset( $fields['billing'] ) && $fields['billing'] ) {
					$fields['billing']['wps_wc_autoresponder_optin'] = $general_field;
				} else {
					$fields['billing'] = array( 'wps_wc_autoresponder_optin' => $general_field );
				}
			}
		}

		if ( in_array( get_option( 'wps_wc_autoresponder_general_subscribe_to', 'global_list' ), array( 'product_list', 'both' ) ) && WC()->cart && WC()->cart->get_cart() ) {
			foreach ( WC()->cart->get_cart() as $cart_item ) {
				$product_id = siar( $cart_item, 'product_id' );

				if ( ! get_post_meta( $product_id, 'wps_wc_autoresponder_product_enable', true ) || ! wc_string_to_bool( get_post_meta( $product_id, 'wps_wc_autoresponder_product_opt_in_field', true ) ) ) {
					continue;
				}

				$opt_in_label = get_post_meta( $product_id, 'wps_wc_autoresponder_product_opt_in_label', true );
				$opt_in_label = ! empty( $opt_in_label ) ? $opt_in_label : esc_html__( 'Subscribe to the newsletter', 'wps-woocommerce-autoresponder' );

				$product_field = array(
					'label'   => esc_html( $opt_in_label ),
					'type'    => 'checkbox',
					'class'   => array( 'form-row-wide' ),
					'default' => get_post_meta( $product_id, 'wps_wc_autoresponder_product_opt_in_checked', true ),
				);

				if ( 'order' === get_post_meta( $product_id, 'wps_wc_autoresponder_product_opt_in_place', true ) ) {
					if ( isset( $fields['order'] ) && $fields['order'] ) {
						$fields['order'][ 'wps_wc_autoresponder_optin_' . $product_id ] = $product_field;
					} else {
						$fields['order'] = array( 'wps_wc_autoresponder_optin_' . $product_id => $product_field );
					}
				} else {
					if ( isset( $fields['billing'] ) && $fields['billing'] ) {
						$fields['billing'][ 'wps_wc_autoresponder_optin_' . $product_id ] = $product_field;
					} else {
						$fields['billing'] = array( 'wps_wc_autoresponder_optin_' . $product_id => $product_field );
					}
				}
			}
		}

		return $fields;
	}

	public function save_opt_in_checkout_fields( $order_id, $data = null ) {
		WPS_WooCommerce_Autoresponder()->log(
			array(
				__METHOD__,
				'order_id' => $order_id,
			)
		);

		if ( 'yes' === get_option( 'wps_wc_autoresponder_general_opt_in_field', 'no' ) && in_array( get_option( 'wps_wc_autoresponder_general_subscribe_to', 'global_list' ), array( 'global_list', 'both' ) ) ) {
			update_post_meta( $order_id, 'wps_wc_autoresponder_optin', isset( $_POST['wps_wc_autoresponder_optin'] ) );
		}

		if ( in_array( get_option( 'wps_wc_autoresponder_general_subscribe_to', 'global_list' ), array( 'product_list', 'both' ) ) ) {
			$order = wc_get_order( $order_id );

			if ( $order->get_items() ) {
				foreach ( $order->get_items() as $item ) {
					if ( ! get_post_meta( $item->get_product_id(), 'wps_wc_autoresponder_product_enable', true ) || ! wc_string_to_bool( get_post_meta( $item->get_product_id(), 'wps_wc_autoresponder_product_opt_in_field', true ) ) ) {
						continue;
					}

					update_post_meta( $order_id, 'wps_wc_autoresponder_optin_' . $item->get_product_id(), isset( $_POST[ 'wps_wc_autoresponder_optin_' . $item->get_product_id() ] ) );
				}
			}
		}
	}

	public function subscribe_upon_order_created( $order = false ) {
		WPS_WooCommerce_Autoresponder()->log(
			array(
				__METHOD__,
				'order_id' => is_object( $order ) ? $order->get_id() : $order,
			)
		);

		$this->subscribe_upon_status( 'order_created', $order );
	}

	public function subscribe_upon_order_processing( $order = false ) {
		WPS_WooCommerce_Autoresponder()->log(
			array(
				__METHOD__,
				'order_id' => is_object( $order ) ? $order->get_id() : $order,
			)
		);

		$this->subscribe_upon_status( 'order_processing', $order );
	}

	public function subscribe_upon_order_completed( $order = false ) {
		WPS_WooCommerce_Autoresponder()->log(
			array(
				__METHOD__,
				'order_id' => is_object( $order ) ? $order->get_id() : $order,
			)
		);

		$this->subscribe_upon_status( 'order_completed', $order );
	}

	public function subscribe_upon_payment_complete( $order = false ) {
		WPS_WooCommerce_Autoresponder()->log(
			array(
				__METHOD__,
				'order_id' => is_object( $order ) ? $order->get_id() : $order,
			)
		);

		$this->subscribe_upon_status( 'payment_complete', $order );
	}

	public function subscribe_upon_status( $status, $order ) {
		if ( ! is_object( $order ) ) {
			$order = wc_get_order( $order );
		}

		if ( ! $order || ! $status ) {
			return;
		}

		WPS_WooCommerce_Autoresponder()->log(
			array(
				__METHOD__,
				'status'   => $status,
				'order_id' => $order->get_id(),
			)
		);

		if ( $status === get_option( 'wps_wc_autoresponder_general_subscribe_upon', 'order_created' ) && in_array( get_option( 'wps_wc_autoresponder_general_subscribe_to', 'global_list' ), array( 'global_list', 'both' ) ) ) {
			if ( 'no' === get_option( 'wps_wc_autoresponder_general_opt_in_field', 'no' ) ) {
				$this->subscribe_general_lists( $order );
			} elseif ( 'yes' === get_option( 'wps_wc_autoresponder_general_opt_in_field', 'no' ) && get_post_meta( $order->get_id(), 'wps_wc_autoresponder_optin', true ) ) {
				$this->subscribe_general_lists( $order );
			}
		}

		if ( in_array( get_option( 'wps_wc_autoresponder_general_subscribe_to', 'global_list' ), array( 'product_list', 'both' ) ) && $order->get_items() ) {
			foreach ( $order->get_items() as $item ) {
				if ( ! get_post_meta( $item->get_product_id(), 'wps_wc_autoresponder_product_enable', true ) || $status !== get_post_meta( $item->get_product_id(), 'wps_wc_autoresponder_product_subscribe_upon', true ) ) {
					continue;
				}

				if ( 'no' === get_post_meta( $item->get_product_id(), 'wps_wc_autoresponder_product_opt_in_field', true ) ) {
					$this->subscribe_product_lists( $order, $item->get_product_id() );
				} elseif ( 'yes' === get_post_meta( $item->get_product_id(), 'wps_wc_autoresponder_product_opt_in_field', true ) && get_post_meta( $order->get_id(), 'wps_wc_autoresponder_optin_' . $item->get_product_id(), true ) ) {
					$this->subscribe_product_lists( $order, $item->get_product_id() );
				}
			}
		}
	}

	public function subscribe_general_lists( $order ) {
		WPS_WooCommerce_Autoresponder()->log(
			array(
				__METHOD__,
				'order_id' => $order->get_id(),
			)
		);

		foreach ( $this->autoresponders as $autoresponder ) {
			$list_id = get_option( 'wps_wc_autoresponder_general_' . $autoresponder . '_list', '' );

			if ( ! empty( $list_id ) ) {
				if ( in_array( $autoresponder, array( 'active_campaign', 'mailchimp' ) ) ) {
					$this->subscribe( $autoresponder, $order, $list_id, array( 'tags' => get_option( 'wps_wc_autoresponder_general_' . $autoresponder . '_tags', '' ) ) );
				} else {
					$this->subscribe( $autoresponder, $order, $list_id );
				}
			}

			if ( 'convertkit' === $autoresponder && ! empty( get_option( 'wps_wc_autoresponder_general_' . $autoresponder . '_sequence', '' ) ) ) {
				$this->subscribe( $autoresponder, $order, get_option( 'wps_wc_autoresponder_general_' . $autoresponder . '_sequence', '' ), array( 'is_convertkit_sequence' => 1 ) );
			}
		}
	}

	public function subscribe_product_lists( $order, $product_id ) {
		WPS_WooCommerce_Autoresponder()->log(
			array(
				__METHOD__,
				'order_id'   => $order->get_id(),
				'product_id' => $product_id,
			)
		);

		foreach ( $this->autoresponders as $autoresponder ) {
			$list_id = get_post_meta( $product_id, 'wps_wc_autoresponder_product_' . $autoresponder . '_list', true );
			if ( ! empty( $list_id ) ) {
				if ( in_array( $autoresponder, array( 'active_campaign', 'mailchimp' ) ) ) {
					$this->subscribe( $autoresponder, $order, $list_id, array( 'tags' => get_post_meta( $product_id, 'wps_wc_autoresponder_product_' . $autoresponder . '_tags', true ) ) );
				} else {
					$this->subscribe( $autoresponder, $order, $list_id );
				}
			}

			if ( 'convertkit' === $autoresponder && ! empty( get_post_meta( $product_id, 'wps_wc_autoresponder_product_' . $autoresponder . '_sequence', true ) ) ) {
				$this->subscribe( $autoresponder, $order, get_post_meta( $product_id, 'wps_wc_autoresponder_product_' . $autoresponder . '_sequence', true ), array( 'is_convertkit_sequence' => 1 ) );
			}
		}
	}

	public function subscribe( $autoresponder, $order, $list_id, $args = array() ) {
		if ( ! in_array( $autoresponder, $this->autoresponders ) || ! $order || empty( $list_id ) ) {
			return;
		}

		$email      = $order->get_billing_email();
		$first_name = $order->get_billing_first_name();
		$last_name  = $order->get_billing_last_name();

		$method_name = 'subscribe_' . $autoresponder;

		if ( 'convertkit' === $autoresponder && siar( $args, 'is_convertkit_sequence' ) ) {
			$method_name = 'subscribe_convertkit_sequence';
		}

		WPS_WooCommerce_Autoresponder()->log(
			array(
				__METHOD__,
				'order_id'   => $order->get_id(),
				'list_id'    => $list_id,
				'method'     => $method_name,
				'email'      => $email,
				'first_name' => $first_name,
				'last_name'  => $last_name,
				'tags'       => siar( $args, 'tags' ),
			)
		);

		if ( method_exists( $this, $method_name ) ) {
			if ( in_array( $autoresponder, array( 'active_campaign', 'mailchimp' ) ) ) {
				$this->$method_name( $list_id, $email, $first_name, $last_name, siar( $args, 'tags' ) );
			} else {
				$this->$method_name( $list_id, $email, $first_name, $last_name );
			}
		}
	}

	public function subscribe_mailchimp( $list_id, $email, $first_name, $last_name, $tags = null ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_mailchimp_enable', 'no' ) || 'yes' !== get_option( 'wps_wc_autoresponder_mailchimp_is_connected', 'no' ) || '' === get_option( 'wps_wc_autoresponder_mailchimp_api_key', '' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/mailchimp/class-wps-wc-autoresponder-mailchimp.php';

		WPS_WC_Autoresponder_Mailchimp()->subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
				'tags'       => $tags,
			)
		);
	}

	public function subscribe_aweber( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_aweber_enable', 'no' ) || 'yes' !== get_option( 'wps_wc_autoresponder_aweber_is_connected', 'no' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/aweber/class-wps-wc-autoresponder-aweber.php';

		WPS_WC_Autoresponder_Aweber()->subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function subscribe_getresponse( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_getresponse_enable', 'no' ) || 'yes' !== get_option( 'wps_wc_autoresponder_getresponse_is_connected', 'no' ) || '' === get_option( 'wps_wc_autoresponder_getresponse_api_key', '' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/getresponse/class-wps-wc-autoresponder-getresponse.php';

		WPS_WC_Autoresponder_GetResponse()->subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function subscribe_icontact( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_icontact_enable', 'no' ) || 'yes' !== get_option( 'wps_wc_autoresponder_icontact_is_connected', 'no' ) || '' === get_option( 'wps_wc_autoresponder_icontact_api_app_id', '' ) || '' === get_option( 'wps_wc_autoresponder_icontact_api_username', '' ) || '' === get_option( 'wps_wc_autoresponder_icontact_api_password', '' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/icontact/class-wps-wc-autoresponder-icontact.php';

		WPS_WC_Autoresponder_iContact()->subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function subscribe_infusionsoft( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_infusionsoft_enable', 'no' ) || 'yes' !== get_option( 'wps_wc_autoresponder_infusionsoft_is_connected', 'no' ) || '' === get_option( 'wps_wc_autoresponder_infusionsoft_application_name', '' ) || '' === get_option( 'wps_wc_autoresponder_infusionsoft_api_key', '' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/infusionsoft/class-wps-wc-autoresponder-infusionsoft.php';

		WPS_WC_Autoresponder_Infusionsoft()->subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function subscribe_constant_contact( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_constant_contact_enable', 'no' ) || 'yes' !== get_option( 'wps_wc_autoresponder_constant_contact_is_connected', 'no' ) || '' === get_option( 'wps_wc_autoresponder_constant_contact_api_key', '' ) || '' === get_option( 'wps_wc_autoresponder_constant_contact_access_token', '' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/constant-contact/class-wps-wc-autoresponder-constant-contact.php';

		WPS_WC_Autoresponder_Constant_Contact()->subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function subscribe_campaign_monitor( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_campaign_monitor_enable', 'no' ) || 'yes' !== get_option( 'wps_wc_autoresponder_campaign_monitor_is_connected', 'no' ) || '' === get_option( 'wps_wc_autoresponder_campaign_monitor_api_key', '' ) || '' === get_option( 'wps_wc_autoresponder_campaign_monitor_client_id', '' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/campaign-monitor/class-wps-wc-autoresponder-campaign-monitor.php';

		WPS_WC_Autoresponder_Campaign_Monitor()->subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function subscribe_vertical_response( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_vertical_response_enable', 'no' ) || 'yes' !== get_option( 'wps_wc_autoresponder_vertical_response_is_connected', 'no' ) || '' === get_option( 'wps_wc_autoresponder_vertical_response_username', '' ) || '' === get_option( 'wps_wc_autoresponder_vertical_response_password', '' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/vertical-response/class-wps-wc-autoresponder-vertical-response.php';

		WPS_WC_Autoresponder_Vertical_Response()->subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function subscribe_send_reach( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_send_reach_enable', 'no' ) || 'yes' !== get_option( 'wps_wc_autoresponder_send_reach_is_connected', 'no' ) || '' === get_option( 'wps_wc_autoresponder_send_reach_api_key', '' ) || '' === get_option( 'wps_wc_autoresponder_send_reach_api_secret', '' ) ) {
			return;
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_send_reach_v3', 'no' ) ) {
			require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/send-reach/v3/class-wps-wc-autoresponder-send-reach.php';

			WPS_WC_Autoresponder_Send_Reach()->subscribe(
				$list_id,
				$email,
				array(
					'first_name' => $first_name,
					'last_name'  => $last_name,
				)
			);
		} else {
			require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/send-reach/v1/class-wps-wc-autoresponder-send-reach-legacy.php';

			WPS_WC_Autoresponder_Send_Reach_Legacy()->subscribe(
				$list_id,
				$email,
				array(
					'first_name' => $first_name,
					'last_name'  => $last_name,
				)
			);
		}
	}

	public function subscribe_active_campaign( $list_id, $email, $first_name, $last_name, $tags = null ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_active_campaign_enable', 'no' ) || 'yes' !== get_option( 'wps_wc_autoresponder_active_campaign_is_connected', 'no' ) || '' === get_option( 'wps_wc_autoresponder_active_campaign_api_url', '' ) || '' === get_option( 'wps_wc_autoresponder_active_campaign_api_secret', '' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/active-campaign/class-wps-wc-autoresponder-active-campaign.php';

		WPS_WC_Autoresponder_Active_Campaign()->subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
				'tags'       => $tags,
			)
		);
	}

	public function subscribe_sendinblue( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_sendinblue_enable', 'no' ) || 'yes' !== get_option( 'wps_wc_autoresponder_sendinblue_is_connected', 'no' ) || '' === get_option( 'wps_wc_autoresponder_sendinblue_api_key', '' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/sendinblue/class-wps-wc-autoresponder-sendinblue.php';

		WPS_WC_Autoresponder_Sendinblue()->subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function subscribe_convertkit( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_convertkit_enable', 'no' ) || 'yes' !== get_option( 'wps_wc_autoresponder_convertkit_is_connected', 'no' ) || '' === get_option( 'wps_wc_autoresponder_convertkit_api_key', '' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/convertkit/class-wps-wc-autoresponder-convertkit.php';

		WPS_WC_Autoresponder_ConvertKit()->subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function subscribe_convertkit_sequence( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_convertkit_enable', 'no' ) || 'yes' !== get_option( 'wps_wc_autoresponder_convertkit_is_connected', 'no' ) || '' === get_option( 'wps_wc_autoresponder_convertkit_api_key', '' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/convertkit/class-wps-wc-autoresponder-convertkit.php';

		WPS_WC_Autoresponder_ConvertKit()->subscribe_sequence(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function subscribe_mymail( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_mymail_enable', 'no' ) || ! WPS_WC_Autoresponder_Helper()->is_mymail_support() ) {
			return;
		}

		WPS_WC_Autoresponder_Helper()->mymail_subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function subscribe_wysija( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_wysija_enable', 'no' ) || ! WPS_WC_Autoresponder_Helper()->is_wysija_support() ) {
			return;
		}

		WPS_WC_Autoresponder_Helper()->wysija_subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function subscribe_mailster( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_mailster_enable', 'no' ) || ! WPS_WC_Autoresponder_Helper()->is_mailster_support() ) {
			return;
		}

		WPS_WC_Autoresponder_Helper()->mailster_subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function subscribe_mailpoet( $list_id, $email, $first_name, $last_name ) {
		WPS_WooCommerce_Autoresponder()->log( array( __METHOD__, func_get_args() ) );

		if ( 'yes' !== get_option( 'wps_wc_autoresponder_mailpoet_enable', 'no' ) || ! WPS_WC_Autoresponder_Helper()->is_mailpoet_support() ) {
			return;
		}

		WPS_WC_Autoresponder_Helper()->mailpoet_subscribe(
			$list_id,
			$email,
			array(
				'first_name' => $first_name,
				'last_name'  => $last_name,
			)
		);
	}

	public function connect_autoresponder( $autoresponder ) {
		if ( ! in_array( $autoresponder, $this->autoresponders ) ) {
			return;
		}

		$method_name = 'connect_' . $autoresponder;

		if ( method_exists( $this, $method_name ) ) {
			$this->$method_name();
		}
	}

	public function connect_mailchimp() {
		if ( 'yes' !== get_option( 'wps_wc_autoresponder_mailchimp_enable', 'no' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/mailchimp/class-wps-wc-autoresponder-mailchimp.php';

		$lists = WPS_WC_Autoresponder_Mailchimp()->get_lists();

		if ( $lists ) {
			update_option( 'wps_wc_autoresponder_mailchimp_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_mailchimp_lists', $lists );
		} elseif ( is_array( $lists ) ) {
			update_option( 'wps_wc_autoresponder_mailchimp_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_mailchimp_lists', array() );
			WC_Admin_Settings::add_message( esc_html__( 'Mailchimp connected successfully but there is no list(s) found.', 'wps-woocommerce-autoresponder' ) );
		} else {
			update_option( 'wps_wc_autoresponder_mailchimp_is_connected', 'no' );
			WC_Admin_Settings::add_error( esc_html__( 'Mailchimp connection failed. Please check API details and try again.', 'wps-woocommerce-autoresponder' ) );
		}
	}

	public function connect_aweber() {
		if ( 'yes' !== get_option( 'wps_wc_autoresponder_aweber_enable', 'no' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/aweber/class-wps-wc-autoresponder-aweber.php';

		if ( '' !== get_option( 'wps_wc_autoresponder_aweber_authorization_code', '' ) && get_option( 'wps_wc_autoresponder_aweber_authorization_code', '' ) !== get_option( 'wps_wc_autoresponder_aweber_authorization_code_previous', '' ) ) {
			// Connect API
			if ( WPS_WC_Autoresponder_Aweber()->generate_api() ) {
				update_option( 'wps_wc_autoresponder_aweber_authorization_code_previous', get_option( 'wps_wc_autoresponder_aweber_authorization_code', '' ) );
				update_option( 'wps_wc_autoresponder_aweber_is_connected', 'yes' );
			} else {
				update_option( 'wps_wc_autoresponder_aweber_is_connected', 'no' );
				WC_Admin_Settings::add_error( esc_html__( 'Aweber connection failed. Please check API details and try again.', 'wps-woocommerce-autoresponder' ) );
			}
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_aweber_is_connected', 'no' ) ) {
			$lists = WPS_WC_Autoresponder_Aweber()->get_lists();

			if ( $lists ) {
				update_option( 'wps_wc_autoresponder_aweber_lists', $lists );
			} elseif ( is_array( $lists ) ) {
				update_option( 'wps_wc_autoresponder_aweber_lists', array() );
				WC_Admin_Settings::add_message( esc_html__( 'Aweber connected successfully but there is no list(s) found.', 'wps-woocommerce-autoresponder' ) );
			}
		}
	}

	public function connect_getresponse() {
		if ( 'yes' !== get_option( 'wps_wc_autoresponder_getresponse_enable', 'no' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/getresponse/class-wps-wc-autoresponder-getresponse.php';

		$lists = WPS_WC_Autoresponder_GetResponse()->get_lists();

		if ( $lists ) {
			update_option( 'wps_wc_autoresponder_getresponse_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_getresponse_lists', $lists );
		} elseif ( is_array( $lists ) ) {
			update_option( 'wps_wc_autoresponder_getresponse_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_getresponse_lists', array() );
			WC_Admin_Settings::add_message( esc_html__( 'GetResponse connected successfully but there are no campaign(s) found.', 'wps-woocommerce-autoresponder' ) );
		} else {
			update_option( 'wps_wc_autoresponder_getresponse_is_connected', 'no' );
			WC_Admin_Settings::add_error( esc_html__( 'GetResponse connection failed. Please check API details and try again.', 'wps-woocommerce-autoresponder' ) );
		}
	}

	public function connect_icontact() {
		if ( 'yes' !== get_option( 'wps_wc_autoresponder_icontact_enable', 'no' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/icontact/class-wps-wc-autoresponder-icontact.php';

		$lists = WPS_WC_Autoresponder_iContact()->get_lists();

		if ( $lists ) {
			update_option( 'wps_wc_autoresponder_icontact_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_icontact_lists', $lists );
		} elseif ( is_array( $lists ) ) {
			update_option( 'wps_wc_autoresponder_icontact_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_icontact_lists', array() );
			WC_Admin_Settings::add_message( esc_html__( 'iContact connected successfully but there are no list(s) found.', 'wps-woocommerce-autoresponder' ) );
		} else {
			update_option( 'wps_wc_autoresponder_icontact_is_connected', 'no' );
			WC_Admin_Settings::add_error( esc_html__( 'iContact connection failed. Please check API details and try again.', 'wps-woocommerce-autoresponder' ) );
		}
	}

	public function connect_infusionsoft() {
		if ( 'yes' !== get_option( 'wps_wc_autoresponder_infusionsoft_enable', 'no' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/infusionsoft/class-wps-wc-autoresponder-infusionsoft.php';

		$lists = WPS_WC_Autoresponder_Infusionsoft()->get_lists();

		if ( $lists ) {
			update_option( 'wps_wc_autoresponder_infusionsoft_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_infusionsoft_lists', $lists );
		} elseif ( is_array( $lists ) ) {
			update_option( 'wps_wc_autoresponder_infusionsoft_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_infusionsoft_lists', array() );
			WC_Admin_Settings::add_message( esc_html__( 'Infusionsoft connected successfully but there are no campaign(s) found.', 'wps-woocommerce-autoresponder' ) );
		} else {
			update_option( 'wps_wc_autoresponder_infusionsoft_is_connected', 'no' );
			WC_Admin_Settings::add_error( esc_html__( 'Infusionsoft connection failed. Please check API details and try again.', 'wps-woocommerce-autoresponder' ) );
		}
	}

	public function connect_constant_contact() {
		if ( 'yes' !== get_option( 'wps_wc_autoresponder_constant_contact_enable', 'no' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/constant-contact/class-wps-wc-autoresponder-constant-contact.php';

		$lists = WPS_WC_Autoresponder_Constant_Contact()->get_lists();

		if ( $lists ) {
			update_option( 'wps_wc_autoresponder_constant_contact_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_constant_contact_lists', $lists );
		} elseif ( is_array( $lists ) ) {
			update_option( 'wps_wc_autoresponder_constant_contact_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_constant_contact_lists', array() );
			WC_Admin_Settings::add_message( esc_html__( 'Constant Contact connected successfully but there are no list(s) found.', 'wps-woocommerce-autoresponder' ) );
		} else {
			update_option( 'wps_wc_autoresponder_constant_contact_is_connected', 'no' );
			WC_Admin_Settings::add_error( esc_html__( 'Constant Contact connection failed. Please check API details and try again.', 'wps-woocommerce-autoresponder' ) );
		}
	}

	public function connect_campaign_monitor() {
		if ( 'yes' !== get_option( 'wps_wc_autoresponder_campaign_monitor_enable', 'no' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/campaign-monitor/class-wps-wc-autoresponder-campaign-monitor.php';

		$lists = WPS_WC_Autoresponder_Campaign_Monitor()->get_lists();

		if ( $lists ) {
			update_option( 'wps_wc_autoresponder_campaign_monitor_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_campaign_monitor_lists', $lists );
		} elseif ( is_array( $lists ) ) {
			update_option( 'wps_wc_autoresponder_campaign_monitor_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_campaign_monitor_lists', array() );
			WC_Admin_Settings::add_message( esc_html__( 'Campaign Monitor connected successfully but there are no list(s) found.', 'wps-woocommerce-autoresponder' ) );
		} else {
			update_option( 'wps_wc_autoresponder_campaign_monitor_is_connected', 'no' );
			WC_Admin_Settings::add_error( esc_html__( 'Campaign Monitor connection failed. Please check API details and try again.', 'wps-woocommerce-autoresponder' ) );
		}
	}

	public function connect_vertical_response() {
		if ( 'yes' !== get_option( 'wps_wc_autoresponder_vertical_response_enable', 'no' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/vertical-response/class-wps-wc-autoresponder-vertical-response.php';

		$lists = WPS_WC_Autoresponder_Vertical_Response()->get_lists();

		if ( $lists ) {
			update_option( 'wps_wc_autoresponder_vertical_response_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_vertical_response_lists', $lists );
		} elseif ( is_array( $lists ) ) {
			update_option( 'wps_wc_autoresponder_vertical_response_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_vertical_response_lists', array() );
			WC_Admin_Settings::add_message( esc_html__( 'VerticalResponse connected successfully but there are no list(s) found.', 'wps-woocommerce-autoresponder' ) );
		} else {
			update_option( 'wps_wc_autoresponder_vertical_response_is_connected', 'no' );
			WC_Admin_Settings::add_error( esc_html__( 'VerticalResponse connection failed. Please check API details and try again.', 'wps-woocommerce-autoresponder' ) );
		}
	}

	public function connect_send_reach() {
		if ( 'yes' !== get_option( 'wps_wc_autoresponder_send_reach_enable', 'no' ) ) {
			return;
		}

		if ( 'yes' === get_option( 'wps_wc_autoresponder_send_reach_v3', 'no' ) ) {
			require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/send-reach/v3/class-wps-wc-autoresponder-send-reach.php';

			$lists = WPS_WC_Autoresponder_Send_Reach()->get_lists();
		} else {
			require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/send-reach/v1/class-wps-wc-autoresponder-send-reach-legacy.php';

			$lists = WPS_WC_Autoresponder_Send_Reach_Legacy()->get_lists();
		}

		if ( $lists ) {
			update_option( 'wps_wc_autoresponder_send_reach_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_send_reach_lists', $lists );
		} elseif ( is_array( $lists ) ) {
			update_option( 'wps_wc_autoresponder_send_reach_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_send_reach_lists', array() );
			WC_Admin_Settings::add_message( esc_html__( 'SendReach connected successfully but there are no list(s) found.', 'wps-woocommerce-autoresponder' ) );
		} else {
			update_option( 'wps_wc_autoresponder_send_reach_is_connected', 'no' );
			WC_Admin_Settings::add_error( esc_html__( 'SendReach connection failed. Please check API details and try again.', 'wps-woocommerce-autoresponder' ) );
		}
	}

	public function connect_active_campaign() {
		if ( 'yes' !== get_option( 'wps_wc_autoresponder_active_campaign_enable', 'no' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/active-campaign/class-wps-wc-autoresponder-active-campaign.php';

		$lists = WPS_WC_Autoresponder_Active_Campaign()->get_lists();

		if ( $lists ) {
			update_option( 'wps_wc_autoresponder_active_campaign_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_active_campaign_lists', $lists );
		} elseif ( is_array( $lists ) ) {
			update_option( 'wps_wc_autoresponder_active_campaign_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_active_campaign_lists', array() );
			WC_Admin_Settings::add_message( esc_html__( 'ActiveCampaign connected successfully but there are no list(s) found.', 'wps-woocommerce-autoresponder' ) );
		} else {
			update_option( 'wps_wc_autoresponder_active_campaign_is_connected', 'no' );
			WC_Admin_Settings::add_error( esc_html__( 'ActiveCampaign connection failed. Please check API details and try again.', 'wps-woocommerce-autoresponder' ) );
		}
	}

	public function connect_sendinblue() {
		if ( 'yes' !== get_option( 'wps_wc_autoresponder_sendinblue_enable', 'no' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/sendinblue/class-wps-wc-autoresponder-sendinblue.php';

		$lists = WPS_WC_Autoresponder_Sendinblue()->get_lists();

		if ( $lists ) {
			update_option( 'wps_wc_autoresponder_sendinblue_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_sendinblue_lists', $lists );
		} elseif ( is_array( $lists ) ) {
			update_option( 'wps_wc_autoresponder_sendinblue_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_sendinblue_lists', array() );
			WC_Admin_Settings::add_message( esc_html__( 'Sendinblue connected successfully but there are no list(s) found.', 'wps-woocommerce-autoresponder' ) );
		} else {
			update_option( 'wps_wc_autoresponder_sendinblue_is_connected', 'no' );
			WC_Admin_Settings::add_error( esc_html__( 'Sendinblue connection failed. Please check API details and try again.', 'wps-woocommerce-autoresponder' ) );
		}
	}

	public function connect_convertkit() {
		if ( 'yes' !== get_option( 'wps_wc_autoresponder_convertkit_enable', 'no' ) ) {
			return;
		}

		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/autoresponders/convertkit/class-wps-wc-autoresponder-convertkit.php';

		$lists = WPS_WC_Autoresponder_ConvertKit()->get_lists();

		if ( $lists ) {
			update_option( 'wps_wc_autoresponder_convertkit_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_convertkit_lists', $lists );
		} elseif ( is_array( $lists ) ) {
			update_option( 'wps_wc_autoresponder_convertkit_is_connected', 'yes' );
			update_option( 'wps_wc_autoresponder_convertkit_lists', array() );
			WC_Admin_Settings::add_message( esc_html__( 'ConvertKit connected successfully but there are no form(s) found.', 'wps-woocommerce-autoresponder' ) );
		} else {
			update_option( 'wps_wc_autoresponder_convertkit_is_connected', 'no' );
			WC_Admin_Settings::add_error( esc_html__( 'ConvertKit connection failed. Please check API details and try again.', 'wps-woocommerce-autoresponder' ) );
		}

		$sequences = WPS_WC_Autoresponder_ConvertKit()->get_sequences();

		if ( $sequences ) {
			update_option( 'wps_wc_autoresponder_convertkit_sequences', $sequences );
		} elseif ( is_array( $sequences ) ) {
			update_option( 'wps_wc_autoresponder_convertkit_sequences', array() );
		}
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WC_Autoresponder_Subscribe() {
	return WPS_WC_Autoresponder_Subscribe::get_instance();
}

$GLOBALS['WPS_WC_Autoresponder_Subscribe'] = WPS_WC_Autoresponder_Subscribe();
