<?php
/**
 * Plugin Name: WooCommerce Autoresponder
 * Plugin URI: https://wpstriker.com/plugins
 * Description: Add customers to your autoresponder list during cart checkout or order completed.
 * Version: 3.0.2
 * Author: wpstriker
 * Author URI: https://wpstriker.com
 * Text Domain: wps-woocommerce-autoresponder
 * Domain Path: /languages/
 * Requires at least: 5.0
 * Requires PHP: 7.0
 * WC requires at least: 4.0
 * WC tested up to: 5.8.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

define( 'WPS_WOOCOMMERCE_AUTORESPONDER_VERSION', '3.0.2' );
define( 'WPS_WOOCOMMERCE_AUTORESPONDER_FILE', __FILE__ );
define( 'WPS_WOOCOMMERCE_AUTORESPONDER_SLUG', 'wps-woocommerce-autoresponder' );
define( 'WPS_WOOCOMMERCE_AUTORESPONDER_BASENAME', plugin_basename( __FILE__ ) );
define( 'WPS_WOOCOMMERCE_AUTORESPONDER_URL', untrailingslashit( plugin_dir_url( __FILE__ ) ) );
define( 'WPS_WOOCOMMERCE_AUTORESPONDER_DIR', untrailingslashit( plugin_dir_path( __FILE__ ) ) );
define( 'WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL', 'https://wcautoresponder.wpstriker.com/documentation' );
define( 'WPS_WOOCOMMERCE_AUTORESPONDER_SUPPORT_URL', 'https://support.wpstriker.com' );

class WPS_WooCommerce_Autoresponder {

	protected static $instance;

	public function __construct() {
		if ( ! $this->is_woocommerce_active() ) {
			return; // WooCommerce must be installed and activated.
		}

		$this->includes();

		add_action( 'init', array( $this, 'load_text_domain' ) );

		if ( is_admin() ) {
			add_filter( 'plugin_action_links_' . WPS_WOOCOMMERCE_AUTORESPONDER_BASENAME, array( $this, 'add_plugin_action_links' ), 20 );
			add_filter( 'plugin_row_meta', array( $this, 'plugin_row_meta' ), 20, 2 );
			add_filter( 'woocommerce_get_settings_pages', array( $this, 'add_wc_settings_page' ), 20, 1 );
			add_action( 'add_meta_boxes', array( $this, 'add_product_meta_box' ), 20 );
			add_action( 'save_post_product', array( $this, 'save_product_meta' ), 20 );
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ), 20, 1 );
		}
	}

	public function is_woocommerce_active() {
		require_once ABSPATH . 'wp-admin/includes/plugin.php';

		if ( ! is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
			return false;
		}

		return true;
	}

	public function includes() {
		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/functions.php';
		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/class-wps-wc-autoresponder-helper.php';
		require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/class-wps-wc-autoresponder-subscribe.php';

		if ( is_admin() ) {
			require_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/class-wps-wc-autoresponder-plugin-update.php';
		}
	}

	public function load_text_domain() {
		load_plugin_textdomain( 'wps-woocommerce-autoresponder', false, WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/languages/' );
	}

	public function add_plugin_action_links( $links ) {
		$action_links = array(
			'settings' => '<a href="' . esc_url( admin_url( 'admin.php?page=wc-settings&tab=wps_wc_autoresponder' ) ) . '" aria-label="' . esc_attr__( 'View WooCommerce Autoresponder settings', 'wps-woocommerce-autoresponder' ) . '">' . esc_html__( 'Settings', 'wps-woocommerce-autoresponder' ) . '</a>',
		);

		return array_merge( $action_links, $links );
	}

	public static function plugin_row_meta( $links, $file ) {
		if ( WPS_WOOCOMMERCE_AUTORESPONDER_BASENAME !== $file ) {
			return $links;
		}

		$row_meta = array(
			'docs'    => '<a href="' . esc_url( WPS_WOOCOMMERCE_AUTORESPONDER_DOC_URL ) . '" aria-label="' . esc_attr__( 'View WooCommerce Autoresponder documentation', 'wps-woocommerce-autoresponder' ) . '">' . esc_html__( 'Documentation', 'wps-woocommerce-autoresponder' ) . '</a>',
			'support' => '<a href="' . esc_url( WPS_WOOCOMMERCE_AUTORESPONDER_SUPPORT_URL ) . '" aria-label="' . esc_attr__( 'Visit premium customer support', 'wps-woocommerce-autoresponder' ) . '">' . esc_html__( 'Premium support', 'wps-woocommerce-autoresponder' ) . '</a>',
		);

		return array_merge( $links, $row_meta );
	}

	public function add_wc_settings_page( $settings ) {
		$settings[] = include WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/class-wps-wc-autoresponder-settings.php';

		return $settings;
	}

	public function add_product_meta_box() {
		add_meta_box( 'wc_autoresponder_meta_setting', esc_html__( 'WooCommerce Autoresponder product list settings', 'wps-woocommerce-autoresponder' ), array( $this, 'output_product_meta_box' ), 'product', 'normal', 'default' );
	}

	public function output_product_meta_box( $post, $metabox = null ) {
		if ( ! isset( $post->ID ) ) {
			return;
		}

		include_once WPS_WOOCOMMERCE_AUTORESPONDER_DIR . '/includes/wps-wc-autoresponder-product-meta-box.php';
	}

	public function save_product_meta( $post_ID ) {
		// bail out if this is an autosave
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		// Save General Settings
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_enable', isset( $_POST['wps_wc_autoresponder_product_enable'] ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_subscribe_upon', sipost( 'wps_wc_autoresponder_product_subscribe_upon' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_opt_in_field', sipost( 'wps_wc_autoresponder_product_opt_in_field' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_opt_in_label', sipost( 'wps_wc_autoresponder_product_opt_in_label' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_opt_in_place', sipost( 'wps_wc_autoresponder_product_opt_in_place' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_opt_in_checked', isset( $_POST['wps_wc_autoresponder_product_opt_in_checked'] ) );

		// Save Autoresponder Lists
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_mailchimp_list', sipost( 'wps_wc_autoresponder_product_mailchimp_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_mailchimp_tags', sipost( 'wps_wc_autoresponder_product_mailchimp_tags' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_aweber_list', sipost( 'wps_wc_autoresponder_product_aweber_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_getresponse_list', sipost( 'wps_wc_autoresponder_product_getresponse_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_icontact_list', sipost( 'wps_wc_autoresponder_product_icontact_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_infusionsoft_list', sipost( 'wps_wc_autoresponder_product_infusionsoft_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_constant_contact_list', sipost( 'wps_wc_autoresponder_product_constant_contact_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_campaign_monitor_list', sipost( 'wps_wc_autoresponder_product_campaign_monitor_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_vertical_response_list', sipost( 'wps_wc_autoresponder_product_vertical_response_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_send_reach_list', sipost( 'wps_wc_autoresponder_product_send_reach_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_active_campaign_list', sipost( 'wps_wc_autoresponder_product_active_campaign_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_active_campaign_tags', sipost( 'wps_wc_autoresponder_product_active_campaign_tags' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_sendinblue_list', sipost( 'wps_wc_autoresponder_product_sendinblue_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_convertkit_sequence', sipost( 'wps_wc_autoresponder_product_convertkit_sequence' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_mymail_list', sipost( 'wps_wc_autoresponder_product_mymail_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_mailster_list', sipost( 'wps_wc_autoresponder_product_mailster_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_wysija_list', sipost( 'wps_wc_autoresponder_product_wysija_list' ) );
		$this->update_or_delete_post_meta( $post_ID, 'wps_wc_autoresponder_product_mailpoet_list', sipost( 'wps_wc_autoresponder_product_mailpoet_list' ) );
	}

	public function update_or_delete_post_meta( $post_ID, $meta_key, $meta_value ) {
		if ( siblank( $meta_value ) ) {
			$updated = delete_post_meta( $post_ID, $meta_key );
		} else {
			$updated = update_post_meta( $post_ID, $meta_key, $meta_value );
		}

		return (bool) $updated;
	}

	public function admin_scripts( $hook = '' ) {
		wp_enqueue_script( 'wps-woocommerce-autoresponder', WPS_WOOCOMMERCE_AUTORESPONDER_URL . '/assets/js/wps-woocommerce-autoresponder.js' );
	}

	public function log( $message ) {
		if ( function_exists( 'wc_get_logger' ) && 'yes' === get_option( 'wps_wc_autoresponder_debug', 'no' ) ) {
			wc_get_logger()->debug( print_r( $message, true ), array( 'source' => WPS_WOOCOMMERCE_AUTORESPONDER_SLUG ) );
		}
	}

	public static function get_instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}
}

function WPS_WooCommerce_Autoresponder() {
	return WPS_WooCommerce_Autoresponder::get_instance();
}

$GLOBALS[ WPS_WOOCOMMERCE_AUTORESPONDER_SLUG ] = WPS_WooCommerce_Autoresponder();
